/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

package java.util.regex;

/**
 * This class gives us a hashtable that contains canonical
 * decomposition mappings that are generated from
 * http://www.unicode.org/Public/4.0-Update/UnicodeData-4.0.0.txt.
 */
class HashDecompositions{

    private static IntArrHash table = null;

    private HashDecompositions() {
    }

    public static IntArrHash getHashDecompositions() {
        if (table != null) {
            return table;
        } else {
            table = new IntArrHash(2032);
            table.put(0x0929, new int [] {0x0928, 0x093C});
            table.put(0xFA9F, new int [] {0x72AF});
            table.put(0xFA9E, new int [] {0x7235});
            table.put(0xFA9D, new int [] {0x77A7});
            table.put(0xFA9C, new int [] {0x716E});
            table.put(0xFA9B, new int [] {0x701E});
            table.put(0xFA9A, new int [] {0x6F22});
            table.put(0x0BCC, new int [] {0x0BC6, 0x0BD7});
            table.put(0x0BCB, new int [] {0x0BC7, 0x0BBE});
            table.put(0x0BCA, new int [] {0x0BC6, 0x0BBE});
            table.put(0xFA99, new int [] {0x6ECB});
            table.put(0xFA98, new int [] {0x6EDB});
            table.put(0xFA97, new int [] {0x6D41});
            table.put(0xFA96, new int [] {0x6BBA});
            table.put(0xFA95, new int [] {0x6B79});
            table.put(0xFA94, new int [] {0x6756});
            table.put(0xFA93, new int [] {0x671B});
            table.put(0xFA92, new int [] {0x6717});
            table.put(0x1D164, new int [] {0x1D158, 0x1D165, 0x1D172});
            table.put(0xFA91, new int [] {0x6674});
            table.put(0x1D163, new int [] {0x1D158, 0x1D165, 0x1D171});
            table.put(0xFA90, new int [] {0x6556});
            table.put(0x1D162, new int [] {0x1D158, 0x1D165, 0x1D170});
            table.put(0x1D161, new int [] {0x1D158, 0x1D165, 0x1D16F});
            table.put(0x1D160, new int [] {0x1D158, 0x1D165, 0x1D16E});
            table.put(0xFA8F, new int [] {0x6452});
            table.put(0xFA8E, new int [] {0x641C});
            table.put(0xFA8D, new int [] {0x63C4});
            table.put(0xFA8C, new int [] {0x6234});
            table.put(0x1D15F, new int [] {0x1D158, 0x1D165});
            table.put(0xFA8B, new int [] {0x61F2});
            table.put(0x1D15E, new int [] {0x1D157, 0x1D165});
            table.put(0xFA8A, new int [] {0x6160});
            table.put(0xFA89, new int [] {0x618E});
            table.put(0xFA88, new int [] {0x6108});
            table.put(0xFA87, new int [] {0x614E});
            table.put(0xFA86, new int [] {0x60D8});
            table.put(0xFA85, new int [] {0x5FAD});
            table.put(0xFA84, new int [] {0x5F69});
            table.put(0xFA83, new int [] {0x5ED9});
            table.put(0xFA82, new int [] {0x5ED2});
            table.put(0xFA81, new int [] {0x5B28});
            table.put(0xFA80, new int [] {0x5A62});
            table.put(0xFA7F, new int [] {0x5954});
            table.put(0x1FFD, new int [] {0x00B4});
            table.put(0xFA7E, new int [] {0x5944});
            table.put(0x1FFC, new int [] {0x03A9, 0x0345});
            table.put(0xFA7D, new int [] {0x58B3});
            table.put(0x1FFB, new int [] {0x03A9, 0x0301});
            table.put(0xFA7C, new int [] {0x585A});
            table.put(0x1FFA, new int [] {0x03A9, 0x0300});
            table.put(0xFA7B, new int [] {0x55E2});
            table.put(0xFA7A, new int [] {0x5599});
            table.put(0x219B, new int [] {0x2192, 0x0338});
            table.put(0x219A, new int [] {0x2190, 0x0338});
            table.put(0x1FF9, new int [] {0x039F, 0x0301});
            table.put(0x1FF8, new int [] {0x039F, 0x0300});
            table.put(0xFA79, new int [] {0x5555});
            table.put(0x1FF7, new int [] {0x03C9, 0x0342, 0x0345});
            table.put(0xFA78, new int [] {0x559D});
            table.put(0x1FF6, new int [] {0x03C9, 0x0342});
            table.put(0xFA77, new int [] {0x52FA});
            table.put(0xFA76, new int [] {0x52C7});
            table.put(0x1FF4, new int [] {0x03C9, 0x0301, 0x0345});
            table.put(0xFA75, new int [] {0x5180});
            table.put(0x1FF3, new int [] {0x03C9, 0x0345});
            table.put(0xFA74, new int [] {0x5145});
            table.put(0x1FF2, new int [] {0x03C9, 0x0300, 0x0345});
            table.put(0xFA73, new int [] {0x4F80});
            table.put(0xFA72, new int [] {0x5168});
            table.put(0xFA71, new int [] {0x51B5});
            table.put(0xFA70, new int [] {0x4E26});
            table.put(0x1FEF, new int [] {0x0060});
            table.put(0x1FEE, new int [] {0x00A8, 0x0301});
            table.put(0x1FED, new int [] {0x00A8, 0x0300});
            table.put(0x1FEC, new int [] {0x03A1, 0x0314});
            table.put(0x1FEB, new int [] {0x03A5, 0x0301});
            table.put(0x1FEA, new int [] {0x03A5, 0x0300});
            table.put(0xFA6A, new int [] {0x983B});
            table.put(0x1FE9, new int [] {0x03A5, 0x0304});
            table.put(0x1FE8, new int [] {0x03A5, 0x0306});
            table.put(0xFA69, new int [] {0x97FF});
            table.put(0x1FE7, new int [] {0x03C5, 0x0308, 0x0342});
            table.put(0xFA68, new int [] {0x96E3});
            table.put(0x1FE6, new int [] {0x03C5, 0x0342});
            table.put(0xFA67, new int [] {0x9038});
            table.put(0x1FE5, new int [] {0x03C1, 0x0314});
            table.put(0xFA66, new int [] {0x8FB6});
            table.put(0x1FE4, new int [] {0x03C1, 0x0313});
            table.put(0xFA65, new int [] {0x8D08});
            table.put(0x1FE3, new int [] {0x03C5, 0x0308, 0x0301});
            table.put(0xFA64, new int [] {0x8CD3});
            table.put(0x1FE2, new int [] {0x03C5, 0x0308, 0x0300});
            table.put(0xFA63, new int [] {0x8B39});
            table.put(0x1FE1, new int [] {0x03C5, 0x0304});
            table.put(0xFA62, new int [] {0x8B01});
            table.put(0x1FE0, new int [] {0x03C5, 0x0306});
            table.put(0xFA61, new int [] {0x8996});
            table.put(0xFA60, new int [] {0x8910});
            table.put(0x1FDF, new int [] {0x1FFE, 0x0342});
            table.put(0x1FDE, new int [] {0x1FFE, 0x0301});
            table.put(0xFA5F, new int [] {0x8457});
            table.put(0x1FDD, new int [] {0x1FFE, 0x0300});
            table.put(0xFA5E, new int [] {0x8279});
            table.put(0xFA5D, new int [] {0x8279});
            table.put(0x1FDB, new int [] {0x0399, 0x0301});
            table.put(0xFA5C, new int [] {0x81ED});
            table.put(0x1FDA, new int [] {0x0399, 0x0300});
            table.put(0xFA5B, new int [] {0x8005});
            table.put(0xFA5A, new int [] {0x7F72});
            table.put(0x1FD9, new int [] {0x0399, 0x0304});
            table.put(0x1FD8, new int [] {0x0399, 0x0306});
            table.put(0xFA59, new int [] {0x7E41});
            table.put(0x1FD7, new int [] {0x03B9, 0x0308, 0x0342});
            table.put(0xFA58, new int [] {0x7E09});
            table.put(0x1FD6, new int [] {0x03B9, 0x0342});
            table.put(0xFA57, new int [] {0x7DF4});
            table.put(0xFA56, new int [] {0x7BC0});
            table.put(0xFA55, new int [] {0x7A81});
            table.put(0x1FD3, new int [] {0x03B9, 0x0308, 0x0301});
            table.put(0xFA54, new int [] {0x7A40});
            table.put(0x1FD2, new int [] {0x03B9, 0x0308, 0x0300});
            table.put(0xFA53, new int [] {0x798E});
            table.put(0x1FD1, new int [] {0x03B9, 0x0304});
            table.put(0xFA52, new int [] {0x798D});
            table.put(0x1FD0, new int [] {0x03B9, 0x0306});
            table.put(0xFA51, new int [] {0x795D});
            table.put(0xFA50, new int [] {0x7956});
            table.put(0x1FCF, new int [] {0x1FBF, 0x0342});
            table.put(0x1FCE, new int [] {0x1FBF, 0x0301});
            table.put(0xFA4F, new int [] {0x7950});
            table.put(0x1FCD, new int [] {0x1FBF, 0x0300});
            table.put(0xFA4E, new int [] {0x7948});
            table.put(0x1FCC, new int [] {0x0397, 0x0345});
            table.put(0xFA4D, new int [] {0x7949});
            table.put(0x1FCB, new int [] {0x0397, 0x0301});
            table.put(0xFA4C, new int [] {0x793E});
            table.put(0x1FCA, new int [] {0x0397, 0x0300});
            table.put(0xFA4B, new int [] {0x7891});
            table.put(0xFA4A, new int [] {0x7422});
            table.put(0x1FC9, new int [] {0x0395, 0x0301});
            table.put(0x1FC8, new int [] {0x0395, 0x0300});
            table.put(0xFA49, new int [] {0x722B});
            table.put(0x1FC7, new int [] {0x03B7, 0x0342, 0x0345});
            table.put(0xFA48, new int [] {0x716E});
            table.put(0x1FC6, new int [] {0x03B7, 0x0342});
            table.put(0xFA47, new int [] {0x6F22});
            table.put(0xFA46, new int [] {0x6E1A});
            table.put(0x1FC4, new int [] {0x03B7, 0x0301, 0x0345});
            table.put(0xFA45, new int [] {0x6D77});
            table.put(0x1FC3, new int [] {0x03B7, 0x0345});
            table.put(0xFA44, new int [] {0x6885});
            table.put(0x1FC2, new int [] {0x03B7, 0x0300, 0x0345});
            table.put(0xFA43, new int [] {0x6691});
            table.put(0x1FC1, new int [] {0x00A8, 0x0342});
            table.put(0xFA42, new int [] {0x65E2});
            table.put(0xFA41, new int [] {0x654F});
            table.put(0xFA40, new int [] {0x61F2});
            table.put(0x1FBE, new int [] {0x03B9});
            table.put(0xFA3F, new int [] {0x618E});
            table.put(0xFA3E, new int [] {0x6168});
            table.put(0x1FBC, new int [] {0x0391, 0x0345});
            table.put(0xFA3D, new int [] {0x6094});
            table.put(0x1FBB, new int [] {0x0391, 0x0301});
            table.put(0xFA3C, new int [] {0x5C6E});
            table.put(0x1FBA, new int [] {0x0391, 0x0300});
            table.put(0xFA3B, new int [] {0x5C64});
            table.put(0xFA3A, new int [] {0x58A8});
            table.put(0x1FB9, new int [] {0x0391, 0x0304});
            table.put(0x1FB8, new int [] {0x0391, 0x0306});
            table.put(0xFA39, new int [] {0x5840});
            table.put(0x1FB7, new int [] {0x03B1, 0x0342, 0x0345});
            table.put(0xFA38, new int [] {0x5668});
            table.put(0x1FB6, new int [] {0x03B1, 0x0342});
            table.put(0xFA37, new int [] {0x5606});
            table.put(0xFA36, new int [] {0x559D});
            table.put(0x1FB4, new int [] {0x03B1, 0x0301, 0x0345});
            table.put(0xFA35, new int [] {0x5351});
            table.put(0x1FB3, new int [] {0x03B1, 0x0345});
            table.put(0xFA34, new int [] {0x52E4});
            table.put(0x1FB2, new int [] {0x03B1, 0x0300, 0x0345});
            table.put(0xFA33, new int [] {0x52C9});
            table.put(0x1FB1, new int [] {0x03B1, 0x0304});
            table.put(0xFA32, new int [] {0x514D});
            table.put(0x1FB0, new int [] {0x03B1, 0x0306});
            table.put(0xFA31, new int [] {0x50E7});
            table.put(0xFA30, new int [] {0x4FAE});
            table.put(0x1FAF, new int [] {0x03A9, 0x0314, 0x0342, 0x0345});
            table.put(0x1FAE, new int [] {0x03A9, 0x0313, 0x0342, 0x0345});
            table.put(0x1FAD, new int [] {0x03A9, 0x0314, 0x0301, 0x0345});
            table.put(0x1FAC, new int [] {0x03A9, 0x0313, 0x0301, 0x0345});
            table.put(0xFA2D, new int [] {0x9DB4});
            table.put(0x1FAB, new int [] {0x03A9, 0x0314, 0x0300, 0x0345});
            table.put(0xFA2C, new int [] {0x9928});
            table.put(0x1FAA, new int [] {0x03A9, 0x0313, 0x0300, 0x0345});
            table.put(0xFA2B, new int [] {0x98FC});
            table.put(0xFA2A, new int [] {0x98EF});
            table.put(0x1FA9, new int [] {0x03A9, 0x0314, 0x0345});
            table.put(0x1FA8, new int [] {0x03A9, 0x0313, 0x0345});
            table.put(0x1FA7, new int [] {0x03C9, 0x0314, 0x0342, 0x0345});
            table.put(0x1FA6, new int [] {0x03C9, 0x0313, 0x0342, 0x0345});
            table.put(0x1FA5, new int [] {0x03C9, 0x0314, 0x0301, 0x0345});
            table.put(0xFA26, new int [] {0x90FD});
            table.put(0x1FA4, new int [] {0x03C9, 0x0313, 0x0301, 0x0345});
            table.put(0xFA25, new int [] {0x9038});
            table.put(0x1FA3, new int [] {0x03C9, 0x0314, 0x0300, 0x0345});
            table.put(0x1FA2, new int [] {0x03C9, 0x0313, 0x0300, 0x0345});
            table.put(0x1FA1, new int [] {0x03C9, 0x0314, 0x0345});
            table.put(0xFA22, new int [] {0x8AF8});
            table.put(0x1FA0, new int [] {0x03C9, 0x0313, 0x0345});
            table.put(0xFA20, new int [] {0x8612});
            table.put(0xFA1E, new int [] {0x7FBD});
            table.put(0xFA1D, new int [] {0x7CBE});
            table.put(0xFA1C, new int [] {0x9756});
            table.put(0xFA1B, new int [] {0x798F});
            table.put(0xFA1A, new int [] {0x7965});
            table.put(0xFA19, new int [] {0x795E});
            table.put(0xFA18, new int [] {0x793C});
            table.put(0xFA17, new int [] {0x76CA});
            table.put(0xFA16, new int [] {0x732A});
            table.put(0xFA15, new int [] {0x51DE});
            table.put(0xFA12, new int [] {0x6674});
            table.put(0xFA10, new int [] {0x585A});
            table.put(0xFA0D, new int [] {0x55C0});
            table.put(0xFA0C, new int [] {0x5140});
            table.put(0xFA0B, new int [] {0x5ED3});
            table.put(0xFA0A, new int [] {0x898B});
            table.put(0x212B, new int [] {0x0041, 0x030A});
            table.put(0x212A, new int [] {0x004B});
            table.put(0xFA09, new int [] {0x964D});
            table.put(0xFA08, new int [] {0x884C});
            table.put(0xFA07, new int [] {0x8F3B});
            table.put(0xFA06, new int [] {0x66B4});
            table.put(0xFA05, new int [] {0x6D1E});
            table.put(0xFA04, new int [] {0x5B85});
            table.put(0xFA03, new int [] {0x7CD6});
            table.put(0xFA02, new int [] {0x62D3});
            table.put(0x2126, new int [] {0x03A9});
            table.put(0xFA01, new int [] {0x5EA6});
            table.put(0xFA00, new int [] {0x5207});
            table.put(0x0B94, new int [] {0x0B92, 0x0BD7});
            table.put(0x1026, new int [] {0x1025, 0x102E});
            table.put(0x0B5D, new int [] {0x0B22, 0x0B3C});
            table.put(0x0B5C, new int [] {0x0B21, 0x0B3C});
            table.put(0x1F9F, new int [] {0x0397, 0x0314, 0x0342, 0x0345});
            table.put(0x1F9E, new int [] {0x0397, 0x0313, 0x0342, 0x0345});
            table.put(0x1F9D, new int [] {0x0397, 0x0314, 0x0301, 0x0345});
            table.put(0x1F9C, new int [] {0x0397, 0x0313, 0x0301, 0x0345});
            table.put(0x1F9B, new int [] {0x0397, 0x0314, 0x0300, 0x0345});
            table.put(0x1F9A, new int [] {0x0397, 0x0313, 0x0300, 0x0345});
            table.put(0x0B4C, new int [] {0x0B47, 0x0B57});
            table.put(0x0B4B, new int [] {0x0B47, 0x0B3E});
            table.put(0x1F99, new int [] {0x0397, 0x0314, 0x0345});
            table.put(0x1F98, new int [] {0x0397, 0x0313, 0x0345});
            table.put(0x1F97, new int [] {0x03B7, 0x0314, 0x0342, 0x0345});
            table.put(0x1F96, new int [] {0x03B7, 0x0313, 0x0342, 0x0345});
            table.put(0x1F95, new int [] {0x03B7, 0x0314, 0x0301, 0x0345});
            table.put(0x1F94, new int [] {0x03B7, 0x0313, 0x0301, 0x0345});
            table.put(0x1F93, new int [] {0x03B7, 0x0314, 0x0300, 0x0345});
            table.put(0x1F92, new int [] {0x03B7, 0x0313, 0x0300, 0x0345});
            table.put(0x1F91, new int [] {0x03B7, 0x0314, 0x0345});
            table.put(0x1F90, new int [] {0x03B7, 0x0313, 0x0345});
            table.put(0x0B48, new int [] {0x0B47, 0x0B56});
            table.put(0x1F8F, new int [] {0x0391, 0x0314, 0x0342, 0x0345});
            table.put(0x1F8E, new int [] {0x0391, 0x0313, 0x0342, 0x0345});
            table.put(0x1F8D, new int [] {0x0391, 0x0314, 0x0301, 0x0345});
            table.put(0x1F8C, new int [] {0x0391, 0x0313, 0x0301, 0x0345});
            table.put(0x1F8B, new int [] {0x0391, 0x0314, 0x0300, 0x0345});
            table.put(0x1F8A, new int [] {0x0391, 0x0313, 0x0300, 0x0345});
            table.put(0x1F89, new int [] {0x0391, 0x0314, 0x0345});
            table.put(0x1F88, new int [] {0x0391, 0x0313, 0x0345});
            table.put(0x1F87, new int [] {0x03B1, 0x0314, 0x0342, 0x0345});
            table.put(0x1F86, new int [] {0x03B1, 0x0313, 0x0342, 0x0345});
            table.put(0x1F85, new int [] {0x03B1, 0x0314, 0x0301, 0x0345});
            table.put(0x1F84, new int [] {0x03B1, 0x0313, 0x0301, 0x0345});
            table.put(0x1F83, new int [] {0x03B1, 0x0314, 0x0300, 0x0345});
            table.put(0x1F82, new int [] {0x03B1, 0x0313, 0x0300, 0x0345});
            table.put(0x1F81, new int [] {0x03B1, 0x0314, 0x0345});
            table.put(0x1F80, new int [] {0x03B1, 0x0313, 0x0345});
            table.put(0x1F7D, new int [] {0x03C9, 0x0301});
            table.put(0x1F7C, new int [] {0x03C9, 0x0300});
            table.put(0x1F7B, new int [] {0x03C5, 0x0301});
            table.put(0x1F7A, new int [] {0x03C5, 0x0300});
            table.put(0x1F79, new int [] {0x03BF, 0x0301});
            table.put(0x1F78, new int [] {0x03BF, 0x0300});
            table.put(0x1F77, new int [] {0x03B9, 0x0301});
            table.put(0x1F76, new int [] {0x03B9, 0x0300});
            table.put(0x1F75, new int [] {0x03B7, 0x0301});
            table.put(0x0233, new int [] {0x0079, 0x0304});
            table.put(0x1F74, new int [] {0x03B7, 0x0300});
            table.put(0x0232, new int [] {0x0059, 0x0304});
            table.put(0x1F73, new int [] {0x03B5, 0x0301});
            table.put(0x0231, new int [] {0x006F, 0x0307, 0x0304});
            table.put(0x1F72, new int [] {0x03B5, 0x0300});
            table.put(0x0230, new int [] {0x004F, 0x0307, 0x0304});
            table.put(0x1F71, new int [] {0x03B1, 0x0301});
            table.put(0x1F70, new int [] {0x03B1, 0x0300});
            table.put(0x022F, new int [] {0x006F, 0x0307});
            table.put(0x022E, new int [] {0x004F, 0x0307});
            table.put(0x1F6F, new int [] {0x03A9, 0x0314, 0x0342});
            table.put(0x022D, new int [] {0x006F, 0x0303, 0x0304});
            table.put(0x1F6E, new int [] {0x03A9, 0x0313, 0x0342});
            table.put(0x022C, new int [] {0x004F, 0x0303, 0x0304});
            table.put(0x1F6D, new int [] {0x03A9, 0x0314, 0x0301});
            table.put(0x022B, new int [] {0x006F, 0x0308, 0x0304});
            table.put(0x1F6C, new int [] {0x03A9, 0x0313, 0x0301});
            table.put(0x022A, new int [] {0x004F, 0x0308, 0x0304});
            table.put(0x1F6B, new int [] {0x03A9, 0x0314, 0x0300});
            table.put(0x1F6A, new int [] {0x03A9, 0x0313, 0x0300});
            table.put(0x0229, new int [] {0x0065, 0x0327});
            table.put(0x0228, new int [] {0x0045, 0x0327});
            table.put(0x1F69, new int [] {0x03A9, 0x0314});
            table.put(0x0227, new int [] {0x0061, 0x0307});
            table.put(0x1F68, new int [] {0x03A9, 0x0313});
            table.put(0x0226, new int [] {0x0041, 0x0307});
            table.put(0x1F67, new int [] {0x03C9, 0x0314, 0x0342});
            table.put(0x1F66, new int [] {0x03C9, 0x0313, 0x0342});
            table.put(0x1F65, new int [] {0x03C9, 0x0314, 0x0301});
            table.put(0x1F64, new int [] {0x03C9, 0x0313, 0x0301});
            table.put(0x1F63, new int [] {0x03C9, 0x0314, 0x0300});
            table.put(0x1F62, new int [] {0x03C9, 0x0313, 0x0300});
            table.put(0x1F61, new int [] {0x03C9, 0x0314});
            table.put(0x1F60, new int [] {0x03C9, 0x0313});
            table.put(0x021F, new int [] {0x0068, 0x030C});
            table.put(0x021E, new int [] {0x0048, 0x030C});
            table.put(0x1F5F, new int [] {0x03A5, 0x0314, 0x0342});
            table.put(0x1F5D, new int [] {0x03A5, 0x0314, 0x0301});
            table.put(0x021B, new int [] {0x0074, 0x0326});
            table.put(0x021A, new int [] {0x0054, 0x0326});
            table.put(0x1F5B, new int [] {0x03A5, 0x0314, 0x0300});
            table.put(0x0219, new int [] {0x0073, 0x0326});
            table.put(0x0218, new int [] {0x0053, 0x0326});
            table.put(0x1F59, new int [] {0x03A5, 0x0314});
            table.put(0x0217, new int [] {0x0075, 0x0311});
            table.put(0x0216, new int [] {0x0055, 0x0311});
            table.put(0x1F57, new int [] {0x03C5, 0x0314, 0x0342});
            table.put(0x0215, new int [] {0x0075, 0x030F});
            table.put(0x1F56, new int [] {0x03C5, 0x0313, 0x0342});
            table.put(0x0214, new int [] {0x0055, 0x030F});
            table.put(0x1F55, new int [] {0x03C5, 0x0314, 0x0301});
            table.put(0x0213, new int [] {0x0072, 0x0311});
            table.put(0x1F54, new int [] {0x03C5, 0x0313, 0x0301});
            table.put(0x0212, new int [] {0x0052, 0x0311});
            table.put(0x1F53, new int [] {0x03C5, 0x0314, 0x0300});
            table.put(0x0211, new int [] {0x0072, 0x030F});
            table.put(0x1F52, new int [] {0x03C5, 0x0313, 0x0300});
            table.put(0x0210, new int [] {0x0052, 0x030F});
            table.put(0x1F51, new int [] {0x03C5, 0x0314});
            table.put(0x1F50, new int [] {0x03C5, 0x0313});
            table.put(0x020F, new int [] {0x006F, 0x0311});
            table.put(0x020E, new int [] {0x004F, 0x0311});
            table.put(0x020D, new int [] {0x006F, 0x030F});
            table.put(0x020C, new int [] {0x004F, 0x030F});
            table.put(0x1F4D, new int [] {0x039F, 0x0314, 0x0301});
            table.put(0x020B, new int [] {0x0069, 0x0311});
            table.put(0x1F4C, new int [] {0x039F, 0x0313, 0x0301});
            table.put(0x020A, new int [] {0x0049, 0x0311});
            table.put(0x1F4B, new int [] {0x039F, 0x0314, 0x0300});
            table.put(0x1F4A, new int [] {0x039F, 0x0313, 0x0300});
            table.put(0x0209, new int [] {0x0069, 0x030F});
            table.put(0x0208, new int [] {0x0049, 0x030F});
            table.put(0x1F49, new int [] {0x039F, 0x0314});
            table.put(0x0207, new int [] {0x0065, 0x0311});
            table.put(0x1F48, new int [] {0x039F, 0x0313});
            table.put(0x0206, new int [] {0x0045, 0x0311});
            table.put(0x0205, new int [] {0x0065, 0x030F});
            table.put(0x0204, new int [] {0x0045, 0x030F});
            table.put(0x1F45, new int [] {0x03BF, 0x0314, 0x0301});
            table.put(0x0203, new int [] {0x0061, 0x0311});
            table.put(0x1F44, new int [] {0x03BF, 0x0313, 0x0301});
            table.put(0x0202, new int [] {0x0041, 0x0311});
            table.put(0x1F43, new int [] {0x03BF, 0x0314, 0x0300});
            table.put(0x0201, new int [] {0x0061, 0x030F});
            table.put(0x1F42, new int [] {0x03BF, 0x0313, 0x0300});
            table.put(0x0200, new int [] {0x0041, 0x030F});
            table.put(0x1F41, new int [] {0x03BF, 0x0314});
            table.put(0x1F40, new int [] {0x03BF, 0x0313});
            table.put(0x2F9FF, new int [] {0x980B});
            table.put(0x2F9FE, new int [] {0x980B});
            table.put(0x1F3F, new int [] {0x0399, 0x0314, 0x0342});
            table.put(0x2F9FD, new int [] {0x29496});
            table.put(0x1F3E, new int [] {0x0399, 0x0313, 0x0342});
            table.put(0x2F9FC, new int [] {0x4AB2});
            table.put(0x1F3D, new int [] {0x0399, 0x0314, 0x0301});
            table.put(0x2F9FB, new int [] {0x2940A});
            table.put(0x1F3C, new int [] {0x0399, 0x0313, 0x0301});
            table.put(0x2F9FA, new int [] {0x97E0});
            table.put(0x1F3B, new int [] {0x0399, 0x0314, 0x0300});
            table.put(0x1F3A, new int [] {0x0399, 0x0313, 0x0300});
            table.put(0x2F9F9, new int [] {0x4A76});
            table.put(0x2F9F8, new int [] {0x4A6E});
            table.put(0x1F39, new int [] {0x0399, 0x0314});
            table.put(0x2F9F7, new int [] {0x2921A});
            table.put(0x1F38, new int [] {0x0399, 0x0313});
            table.put(0x2F9F6, new int [] {0x29145});
            table.put(0x1F37, new int [] {0x03B9, 0x0314, 0x0342});
            table.put(0x2F9F5, new int [] {0x9723});
            table.put(0x1F36, new int [] {0x03B9, 0x0313, 0x0342});
            table.put(0x2F9F4, new int [] {0x5DB2});
            table.put(0x1F35, new int [] {0x03B9, 0x0314, 0x0301});
            table.put(0x2F9F3, new int [] {0x96C3});
            table.put(0x1F34, new int [] {0x03B9, 0x0313, 0x0301});
            table.put(0x2F9F2, new int [] {0x49E6});
            table.put(0x1F33, new int [] {0x03B9, 0x0314, 0x0300});
            table.put(0x2F9F1, new int [] {0x28D77});
            table.put(0x1F32, new int [] {0x03B9, 0x0313, 0x0300});
            table.put(0x2F9F0, new int [] {0x95B7});
            table.put(0x1F31, new int [] {0x03B9, 0x0314});
            table.put(0x1F30, new int [] {0x03B9, 0x0313});
            table.put(0x2F9EF, new int [] {0x4995});
            table.put(0x2F9EE, new int [] {0x958B});
            table.put(0x1F2F, new int [] {0x0397, 0x0314, 0x0342});
            table.put(0x2F9ED, new int [] {0x28BFA});
            table.put(0x1F2E, new int [] {0x0397, 0x0313, 0x0342});
            table.put(0x2F9EC, new int [] {0x9415});
            table.put(0x1F2D, new int [] {0x0397, 0x0314, 0x0301});
            table.put(0x2F9EB, new int [] {0x93F9});
            table.put(0x1F2C, new int [] {0x0397, 0x0313, 0x0301});
            table.put(0x2F9EA, new int [] {0x927C});
            table.put(0x1F2B, new int [] {0x0397, 0x0314, 0x0300});
            table.put(0x1F2A, new int [] {0x0397, 0x0313, 0x0300});
            table.put(0x2F9E9, new int [] {0x92D8});
            table.put(0x2F9E8, new int [] {0x92D7});
            table.put(0x1F29, new int [] {0x0397, 0x0314});
            table.put(0x2F9E7, new int [] {0x9238});
            table.put(0x1F28, new int [] {0x0397, 0x0313});
            table.put(0x2F9E6, new int [] {0x911B});
            table.put(0x1F27, new int [] {0x03B7, 0x0314, 0x0342});
            table.put(0x2F9E5, new int [] {0x2872E});
            table.put(0x1F26, new int [] {0x03B7, 0x0313, 0x0342});
            table.put(0x2F9E4, new int [] {0x9111});
            table.put(0x1F25, new int [] {0x03B7, 0x0314, 0x0301});
            table.put(0x2F9E3, new int [] {0x90F1});
            table.put(0x1F24, new int [] {0x03B7, 0x0313, 0x0301});
            table.put(0x2F9E2, new int [] {0x9094});
            table.put(0x1F23, new int [] {0x03B7, 0x0314, 0x0300});
            table.put(0x2F9E1, new int [] {0x285ED});
            table.put(0x1F22, new int [] {0x03B7, 0x0313, 0x0300});
            table.put(0x2F9E0, new int [] {0x285D2});
            table.put(0x1F21, new int [] {0x03B7, 0x0314});
            table.put(0x1F20, new int [] {0x03B7, 0x0313});
            table.put(0x2F9DF, new int [] {0x8F38});
            table.put(0x2F9DE, new int [] {0x8ED4});
            table.put(0x2F9DD, new int [] {0x208DE});
            table.put(0x2F9DC, new int [] {0x8DF0});
            table.put(0x1F1D, new int [] {0x0395, 0x0314, 0x0301});
            table.put(0x2F9DB, new int [] {0x8DBC});
            table.put(0x1F1C, new int [] {0x0395, 0x0313, 0x0301});
            table.put(0x2F9DA, new int [] {0x8DCB});
            table.put(0x1F1B, new int [] {0x0395, 0x0314, 0x0300});
            table.put(0x1F1A, new int [] {0x0395, 0x0313, 0x0300});
            table.put(0x2F9D9, new int [] {0x20804});
            table.put(0x2F9D8, new int [] {0x27F2F});
            table.put(0x1F19, new int [] {0x0395, 0x0314});
            table.put(0x2F9D7, new int [] {0x8D77});
            table.put(0x1F18, new int [] {0x0395, 0x0313});
            table.put(0x2F9D6, new int [] {0x8D1B});
            table.put(0x2F9D5, new int [] {0x8CC1});
            table.put(0x2F9D4, new int [] {0x8CAB});
            table.put(0x1F15, new int [] {0x03B5, 0x0314, 0x0301});
            table.put(0x2F9D3, new int [] {0x27CA8});
            table.put(0x1F14, new int [] {0x03B5, 0x0313, 0x0301});
            table.put(0x2F9D2, new int [] {0x8C55});
            table.put(0x1F13, new int [] {0x03B5, 0x0314, 0x0300});
            table.put(0x2F9D1, new int [] {0x8B8A});
            table.put(0x1F12, new int [] {0x03B5, 0x0313, 0x0300});
            table.put(0x2F9D0, new int [] {0x8AED});
            table.put(0x1F11, new int [] {0x03B5, 0x0314});
            table.put(0x1F10, new int [] {0x03B5, 0x0313});
            table.put(0x2F9CF, new int [] {0x8AA0});
            table.put(0x2F9CE, new int [] {0x46C7});
            table.put(0x1F0F, new int [] {0x0391, 0x0314, 0x0342});
            table.put(0x2F9CD, new int [] {0x46BE});
            table.put(0x1F0E, new int [] {0x0391, 0x0313, 0x0342});
            table.put(0x2F9CC, new int [] {0x27966});
            table.put(0x1F0D, new int [] {0x0391, 0x0314, 0x0301});
            table.put(0x2F9CB, new int [] {0x278AE});
            table.put(0x1F0C, new int [] {0x0391, 0x0313, 0x0301});
            table.put(0x2F9CA, new int [] {0x34BB});
            table.put(0x1F0B, new int [] {0x0391, 0x0314, 0x0300});
            table.put(0x1F0A, new int [] {0x0391, 0x0313, 0x0300});
            table.put(0x2F9C9, new int [] {0x88FA});
            table.put(0x2F9C8, new int [] {0x4635});
            table.put(0x1F09, new int [] {0x0391, 0x0314});
            table.put(0x2F9C7, new int [] {0x88DE});
            table.put(0x1F08, new int [] {0x0391, 0x0313});
            table.put(0x2F9C6, new int [] {0x88D7});
            table.put(0x1F07, new int [] {0x03B1, 0x0314, 0x0342});
            table.put(0x2F9C5, new int [] {0x27667});
            table.put(0x1F06, new int [] {0x03B1, 0x0313, 0x0342});
            table.put(0x2F9C4, new int [] {0x8863});
            table.put(0x1F05, new int [] {0x03B1, 0x0314, 0x0301});
            table.put(0x2F9C3, new int [] {0x8860});
            table.put(0x1F04, new int [] {0x03B1, 0x0313, 0x0301});
            table.put(0x2F9C2, new int [] {0x45F9});
            table.put(0x1F03, new int [] {0x03B1, 0x0314, 0x0300});
            table.put(0x2F9C1, new int [] {0x8801});
            table.put(0x1F02, new int [] {0x03B1, 0x0313, 0x0300});
            table.put(0x2F9C0, new int [] {0x87E1});
            table.put(0x1F01, new int [] {0x03B1, 0x0314});
            table.put(0x1F00, new int [] {0x03B1, 0x0313});
            table.put(0x2F9BF, new int [] {0x45D7});
            table.put(0x2F9BE, new int [] {0x8786});
            table.put(0x2F9BD, new int [] {0x876B});
            table.put(0x2F9BC, new int [] {0x8728});
            table.put(0x2F9BB, new int [] {0x8779});
            table.put(0x2F9BA, new int [] {0x86E2});
            table.put(0x2F9B9, new int [] {0x870E});
            table.put(0x2F9B8, new int [] {0x8688});
            table.put(0x2F9B7, new int [] {0x86A9});
            table.put(0x2F9B6, new int [] {0x8669});
            table.put(0x2F9B5, new int [] {0x8667});
            table.put(0x2F9B4, new int [] {0x865C});
            table.put(0x2F9B3, new int [] {0x8650});
            table.put(0x2F9B2, new int [] {0x456B});
            table.put(0x2F9B1, new int [] {0x270D2});
            table.put(0x2F9B0, new int [] {0x26FB1});
            table.put(0x2F9AF, new int [] {0x4561});
            table.put(0x2F9AE, new int [] {0x455D});
            table.put(0x2F9AD, new int [] {0x26F2C});
            table.put(0x2F9AC, new int [] {0x8564});
            table.put(0x2F9AB, new int [] {0x273CA});
            table.put(0x2F9AA, new int [] {0x8516});
            table.put(0x2F9A9, new int [] {0x84F3});
            table.put(0x2F9A8, new int [] {0x84F1});
            table.put(0x2F9A7, new int [] {0x452B});
            table.put(0x2F9A6, new int [] {0x26CD5});
            table.put(0x2F9A5, new int [] {0x26D6B});
            table.put(0x2F9A4, new int [] {0x26C36});
            table.put(0x2F9A3, new int [] {0x83DC});
            table.put(0x2F9A2, new int [] {0x83CC});
            table.put(0x2F9A1, new int [] {0x83CA});
            table.put(0x2F9A0, new int [] {0x8353});
            table.put(0x01FF, new int [] {0x00F8, 0x0301});
            table.put(0x01FE, new int [] {0x00D8, 0x0301});
            table.put(0x01FD, new int [] {0x00E6, 0x0301});
            table.put(0x01FC, new int [] {0x00C6, 0x0301});
            table.put(0x01FB, new int [] {0x0061, 0x030A, 0x0301});
            table.put(0x01FA, new int [] {0x0041, 0x030A, 0x0301});
            table.put(0x01F9, new int [] {0x006E, 0x0300});
            table.put(0x01F8, new int [] {0x004E, 0x0300});
            table.put(0x01F5, new int [] {0x0067, 0x0301});
            table.put(0x01F4, new int [] {0x0047, 0x0301});
            table.put(0x01F0, new int [] {0x006A, 0x030C});
            table.put(0x01EF, new int [] {0x0292, 0x030C});
            table.put(0x01EE, new int [] {0x01B7, 0x030C});
            table.put(0x01ED, new int [] {0x006F, 0x0328, 0x0304});
            table.put(0x01EC, new int [] {0x004F, 0x0328, 0x0304});
            table.put(0x01EB, new int [] {0x006F, 0x0328});
            table.put(0x01EA, new int [] {0x004F, 0x0328});
            table.put(0x01E9, new int [] {0x006B, 0x030C});
            table.put(0x01E8, new int [] {0x004B, 0x030C});
            table.put(0x01E7, new int [] {0x0067, 0x030C});
            table.put(0x01E6, new int [] {0x0047, 0x030C});
            table.put(0x01E3, new int [] {0x00E6, 0x0304});
            table.put(0x01E2, new int [] {0x00C6, 0x0304});
            table.put(0x01E1, new int [] {0x0061, 0x0307, 0x0304});
            table.put(0x01E0, new int [] {0x0041, 0x0307, 0x0304});
            table.put(0x01DF, new int [] {0x0061, 0x0308, 0x0304});
            table.put(0x01DE, new int [] {0x0041, 0x0308, 0x0304});
            table.put(0x01DC, new int [] {0x0075, 0x0308, 0x0300});
            table.put(0x01DB, new int [] {0x0055, 0x0308, 0x0300});
            table.put(0x01DA, new int [] {0x0075, 0x0308, 0x030C});
            table.put(0x01D9, new int [] {0x0055, 0x0308, 0x030C});
            table.put(0x01D8, new int [] {0x0075, 0x0308, 0x0301});
            table.put(0x01D7, new int [] {0x0055, 0x0308, 0x0301});
            table.put(0x01D6, new int [] {0x0075, 0x0308, 0x0304});
            table.put(0x01D5, new int [] {0x0055, 0x0308, 0x0304});
            table.put(0x01D4, new int [] {0x0075, 0x030C});
            table.put(0x01D3, new int [] {0x0055, 0x030C});
            table.put(0x01D2, new int [] {0x006F, 0x030C});
            table.put(0x01D1, new int [] {0x004F, 0x030C});
            table.put(0x01D0, new int [] {0x0069, 0x030C});
            table.put(0x01CF, new int [] {0x0049, 0x030C});
            table.put(0x01CE, new int [] {0x0061, 0x030C});
            table.put(0x01CD, new int [] {0x0041, 0x030C});
            table.put(0x1EF9, new int [] {0x0079, 0x0303});
            table.put(0x1EF8, new int [] {0x0059, 0x0303});
            table.put(0x1EF7, new int [] {0x0079, 0x0309});
            table.put(0x1EF6, new int [] {0x0059, 0x0309});
            table.put(0x1EF5, new int [] {0x0079, 0x0323});
            table.put(0x1EF4, new int [] {0x0059, 0x0323});
            table.put(0x1EF3, new int [] {0x0079, 0x0300});
            table.put(0x1EF2, new int [] {0x0059, 0x0300});
            table.put(0x01B0, new int [] {0x0075, 0x031B});
            table.put(0x1EF1, new int [] {0x0075, 0x031B, 0x0323});
            table.put(0x1EF0, new int [] {0x0055, 0x031B, 0x0323});
            table.put(0x2F99F, new int [] {0x8457});
            table.put(0x01AF, new int [] {0x0055, 0x031B});
            table.put(0x2F99E, new int [] {0x83E7});
            table.put(0x1EEF, new int [] {0x0075, 0x031B, 0x0303});
            table.put(0x2F99D, new int [] {0x83BD});
            table.put(0x1EEE, new int [] {0x0055, 0x031B, 0x0303});
            table.put(0x2F99C, new int [] {0x8323});
            table.put(0x1EED, new int [] {0x0075, 0x031B, 0x0309});
            table.put(0x2F99B, new int [] {0x83AD});
            table.put(0x1EEC, new int [] {0x0055, 0x031B, 0x0309});
            table.put(0x2F99A, new int [] {0x8363});
            table.put(0x1EEB, new int [] {0x0075, 0x031B, 0x0300});
            table.put(0x1EEA, new int [] {0x0055, 0x031B, 0x0300});
            table.put(0x2F999, new int [] {0x831D});
            table.put(0x2F998, new int [] {0x82E5});
            table.put(0x1EE9, new int [] {0x0075, 0x031B, 0x0301});
            table.put(0x2F997, new int [] {0x26B3C});
            table.put(0x1EE8, new int [] {0x0055, 0x031B, 0x0301});
            table.put(0x2F996, new int [] {0x82E6});
            table.put(0x1EE7, new int [] {0x0075, 0x0309});
            table.put(0x2F995, new int [] {0x82BD});
            table.put(0x1EE6, new int [] {0x0055, 0x0309});
            table.put(0x2F994, new int [] {0x82B3});
            table.put(0x1EE5, new int [] {0x0075, 0x0323});
            table.put(0x2F993, new int [] {0x82B1});
            table.put(0x1EE4, new int [] {0x0055, 0x0323});
            table.put(0x2F992, new int [] {0x52B3});
            table.put(0x1EE3, new int [] {0x006F, 0x031B, 0x0323});
            table.put(0x2F991, new int [] {0x829D});
            table.put(0x01A1, new int [] {0x006F, 0x031B});
            table.put(0x1EE2, new int [] {0x004F, 0x031B, 0x0323});
            table.put(0x2F990, new int [] {0x828B});
            table.put(0x01A0, new int [] {0x004F, 0x031B});
            table.put(0x1EE1, new int [] {0x006F, 0x031B, 0x0303});
            table.put(0x1EE0, new int [] {0x004F, 0x031B, 0x0303});
            table.put(0x2F98F, new int [] {0x8291});
            table.put(0x2F98E, new int [] {0x446B});
            table.put(0x1EDF, new int [] {0x006F, 0x031B, 0x0309});
            table.put(0x2F98D, new int [] {0x8F9E});
            table.put(0x1EDE, new int [] {0x004F, 0x031B, 0x0309});
            table.put(0x2F98C, new int [] {0x8204});
            table.put(0x1EDD, new int [] {0x006F, 0x031B, 0x0300});
            table.put(0x2F98B, new int [] {0x8201});
            table.put(0x1EDC, new int [] {0x004F, 0x031B, 0x0300});
            table.put(0x2F98A, new int [] {0x2339C});
            table.put(0x1EDB, new int [] {0x006F, 0x031B, 0x0301});
            table.put(0x1EDA, new int [] {0x004F, 0x031B, 0x0301});
            table.put(0x2F989, new int [] {0x23393});
            table.put(0x2F988, new int [] {0x267B5});
            table.put(0x1ED9, new int [] {0x006F, 0x0323, 0x0302});
            table.put(0x2F987, new int [] {0x267A7});
            table.put(0x04F9, new int [] {0x044B, 0x0308});
            table.put(0x1ED8, new int [] {0x004F, 0x0323, 0x0302});
            table.put(0x2F986, new int [] {0x5AB5});
            table.put(0x04F8, new int [] {0x042B, 0x0308});
            table.put(0x1ED7, new int [] {0x006F, 0x0302, 0x0303});
            table.put(0x2F985, new int [] {0x813E});
            table.put(0x1ED6, new int [] {0x004F, 0x0302, 0x0303});
            table.put(0x2F984, new int [] {0x440B});
            table.put(0x1ED5, new int [] {0x006F, 0x0302, 0x0309});
            table.put(0x2F983, new int [] {0x8103});
            table.put(0x04F5, new int [] {0x0447, 0x0308});
            table.put(0x1ED4, new int [] {0x004F, 0x0302, 0x0309});
            table.put(0x2F982, new int [] {0x80B2});
            table.put(0x04F4, new int [] {0x0427, 0x0308});
            table.put(0x1ED3, new int [] {0x006F, 0x0302, 0x0300});
            table.put(0x2F981, new int [] {0x43D5});
            table.put(0x04F3, new int [] {0x0443, 0x030B});
            table.put(0x1ED2, new int [] {0x004F, 0x0302, 0x0300});
            table.put(0x2F980, new int [] {0x2335F});
            table.put(0x04F2, new int [] {0x0423, 0x030B});
            table.put(0x1ED1, new int [] {0x006F, 0x0302, 0x0301});
            table.put(0x04F1, new int [] {0x0443, 0x0308});
            table.put(0x1ED0, new int [] {0x004F, 0x0302, 0x0301});
            table.put(0x04F0, new int [] {0x0423, 0x0308});
            table.put(0x2F97F, new int [] {0x8070});
            table.put(0x2F97E, new int [] {0x265A8});
            table.put(0x1ECF, new int [] {0x006F, 0x0309});
            table.put(0x2F97D, new int [] {0x8060});
            table.put(0x04EF, new int [] {0x0443, 0x0304});
            table.put(0x1ECE, new int [] {0x004F, 0x0309});
            table.put(0x2F97C, new int [] {0x26523});
            table.put(0x04EE, new int [] {0x0423, 0x0304});
            table.put(0x1ECD, new int [] {0x006F, 0x0323});
            table.put(0x2F97B, new int [] {0x264DA});
            table.put(0x04ED, new int [] {0x044D, 0x0308});
            table.put(0x1ECC, new int [] {0x004F, 0x0323});
            table.put(0x2F97A, new int [] {0x8005});
            table.put(0x04EC, new int [] {0x042D, 0x0308});
            table.put(0x1ECB, new int [] {0x0069, 0x0323});
            table.put(0x04EB, new int [] {0x04E9, 0x0308});
            table.put(0x1ECA, new int [] {0x0049, 0x0323});
            table.put(0x04EA, new int [] {0x04E8, 0x0308});
            table.put(0x2F979, new int [] {0x7FFA});
            table.put(0x0DDE, new int [] {0x0DD9, 0x0DDF});
            table.put(0x2F978, new int [] {0x7F95});
            table.put(0x0DDD, new int [] {0x0DD9, 0x0DCF, 0x0DCA});
            table.put(0x1EC9, new int [] {0x0069, 0x0309});
            table.put(0x2F977, new int [] {0x2633E});
            table.put(0x0DDC, new int [] {0x0DD9, 0x0DCF});
            table.put(0x1EC8, new int [] {0x0049, 0x0309});
            table.put(0x2F976, new int [] {0x7F7A});
            table.put(0x1EC7, new int [] {0x0065, 0x0323, 0x0302});
            table.put(0x2F975, new int [] {0x262D9});
            table.put(0x04E7, new int [] {0x043E, 0x0308});
            table.put(0x0DDA, new int [] {0x0DD9, 0x0DCA});
            table.put(0x1EC6, new int [] {0x0045, 0x0323, 0x0302});
            table.put(0x2F974, new int [] {0x4359});
            table.put(0x04E6, new int [] {0x041E, 0x0308});
            table.put(0x1EC5, new int [] {0x0065, 0x0302, 0x0303});
            table.put(0x2F973, new int [] {0x26247});
            table.put(0x04E5, new int [] {0x0438, 0x0308});
            table.put(0x1EC4, new int [] {0x0045, 0x0302, 0x0303});
            table.put(0x2F972, new int [] {0x26228});
            table.put(0x04E4, new int [] {0x0418, 0x0308});
            table.put(0x1EC3, new int [] {0x0065, 0x0302, 0x0309});
            table.put(0x2F971, new int [] {0x4334});
            table.put(0x04E3, new int [] {0x0438, 0x0304});
            table.put(0x1EC2, new int [] {0x0045, 0x0302, 0x0309});
            table.put(0x2F970, new int [] {0x7E45});
            table.put(0x04E2, new int [] {0x0418, 0x0304});
            table.put(0x1EC1, new int [] {0x0065, 0x0302, 0x0300});
            table.put(0x1EC0, new int [] {0x0045, 0x0302, 0x0300});
            table.put(0xF9FF, new int [] {0x523A});
            table.put(0xF9FE, new int [] {0x8336});
            table.put(0x2F96F, new int [] {0x7E02});
            table.put(0xF9FD, new int [] {0x4EC0});
            table.put(0x2F96E, new int [] {0x7DC7});
            table.put(0x1EBF, new int [] {0x0065, 0x0302, 0x0301});
            table.put(0xF9FC, new int [] {0x8B58});
            table.put(0x2F96D, new int [] {0x4301});
            table.put(0x04DF, new int [] {0x0437, 0x0308});
            table.put(0x1EBE, new int [] {0x0045, 0x0302, 0x0301});
            table.put(0xF9FB, new int [] {0x7099});
            table.put(0x2F96C, new int [] {0x7D63});
            table.put(0x04DE, new int [] {0x0417, 0x0308});
            table.put(0x1EBD, new int [] {0x0065, 0x0303});
            table.put(0xF9FA, new int [] {0x72C0});
            table.put(0x2F96B, new int [] {0x25F86});
            table.put(0x04DD, new int [] {0x0436, 0x0308});
            table.put(0x1EBC, new int [] {0x0045, 0x0303});
            table.put(0x2F96A, new int [] {0x7D00});
            table.put(0x04DC, new int [] {0x0416, 0x0308});
            table.put(0x1EBB, new int [] {0x0065, 0x0309});
            table.put(0x04DB, new int [] {0x04D9, 0x0308});
            table.put(0x1EBA, new int [] {0x0045, 0x0309});
            table.put(0x04DA, new int [] {0x04D8, 0x0308});
            table.put(0xF9F9, new int [] {0x7C92});
            table.put(0xF9F8, new int [] {0x7B20});
            table.put(0x2F969, new int [] {0x7CE3});
            table.put(0xF9F7, new int [] {0x7ACB});
            table.put(0x2F968, new int [] {0x7CE8});
            table.put(0x1EB9, new int [] {0x0065, 0x0323});
            table.put(0xF9F6, new int [] {0x81E8});
            table.put(0x2F967, new int [] {0x42A0});
            table.put(0x1EB8, new int [] {0x0045, 0x0323});
            table.put(0xF9F5, new int [] {0x6DCB});
            table.put(0x2F966, new int [] {0x7CD2});
            table.put(0x1EB7, new int [] {0x0061, 0x0323, 0x0306});
            table.put(0xF9F4, new int [] {0x6797});
            table.put(0x2F965, new int [] {0x25C80});
            table.put(0x04D7, new int [] {0x0435, 0x0306});
            table.put(0x1EB6, new int [] {0x0041, 0x0323, 0x0306});
            table.put(0xF9F3, new int [] {0x9E9F});
            table.put(0x2F964, new int [] {0x4227});
            table.put(0x04D6, new int [] {0x0415, 0x0306});
            table.put(0x1EB5, new int [] {0x0061, 0x0306, 0x0303});
            table.put(0xF9F2, new int [] {0x9C57});
            table.put(0x2F963, new int [] {0x7BC9});
            table.put(0x1EB4, new int [] {0x0041, 0x0306, 0x0303});
            table.put(0xF9F1, new int [] {0x96A3});
            table.put(0x2F962, new int [] {0x7BC6});
            table.put(0x1EB3, new int [] {0x0061, 0x0306, 0x0309});
            table.put(0xF9F0, new int [] {0x85FA});
            table.put(0x2F961, new int [] {0x25BAB});
            table.put(0x04D3, new int [] {0x0430, 0x0308});
            table.put(0x1EB2, new int [] {0x0041, 0x0306, 0x0309});
            table.put(0x2F960, new int [] {0x4202});
            table.put(0x04D2, new int [] {0x0410, 0x0308});
            table.put(0x1EB1, new int [] {0x0061, 0x0306, 0x0300});
            table.put(0x04D1, new int [] {0x0430, 0x0306});
            table.put(0x1EB0, new int [] {0x0041, 0x0306, 0x0300});
            table.put(0x04D0, new int [] {0x0410, 0x0306});
            table.put(0xF9EF, new int [] {0x7498});
            table.put(0xF9EE, new int [] {0x71D0});
            table.put(0x2F95F, new int [] {0x7AEE});
            table.put(0xF9ED, new int [] {0x541D});
            table.put(0x2F95E, new int [] {0x25AA7});
            table.put(0x1EAF, new int [] {0x0061, 0x0306, 0x0301});
            table.put(0xF9EC, new int [] {0x6EBA});
            table.put(0x2F95D, new int [] {0x25AA7});
            table.put(0x1EAE, new int [] {0x0041, 0x0306, 0x0301});
            table.put(0xF9EB, new int [] {0x533F});
            table.put(0x2F95C, new int [] {0x2597C});
            table.put(0x1EAD, new int [] {0x0061, 0x0323, 0x0302});
            table.put(0xF9EA, new int [] {0x96E2});
            table.put(0x2F95B, new int [] {0x7A4F});
            table.put(0x1EAC, new int [] {0x0041, 0x0323, 0x0302});
            table.put(0x2F95A, new int [] {0x7A4A});
            table.put(0x1EAB, new int [] {0x0061, 0x0302, 0x0303});
            table.put(0x1EAA, new int [] {0x0041, 0x0302, 0x0303});
            table.put(0xF9E9, new int [] {0x91CC});
            table.put(0xF9E8, new int [] {0x88E1});
            table.put(0x2F959, new int [] {0x7A40});
            table.put(0xF9E7, new int [] {0x88CF});
            table.put(0x2F958, new int [] {0x412F});
            table.put(0x1EA9, new int [] {0x0061, 0x0302, 0x0309});
            table.put(0xF9E6, new int [] {0x7F79});
            table.put(0x2F957, new int [] {0x79EB});
            table.put(0x1EA8, new int [] {0x0041, 0x0302, 0x0309});
            table.put(0xF9E5, new int [] {0x75E2});
            table.put(0x2F956, new int [] {0x798F});
            table.put(0x1EA7, new int [] {0x0061, 0x0302, 0x0300});
            table.put(0xF9E4, new int [] {0x7406});
            table.put(0x2F955, new int [] {0x256C5});
            table.put(0x1EA6, new int [] {0x0041, 0x0302, 0x0300});
            table.put(0xF9E3, new int [] {0x6CE5});
            table.put(0x2F954, new int [] {0x2569A});
            table.put(0x1EA5, new int [] {0x0061, 0x0302, 0x0301});
            table.put(0xF9E2, new int [] {0x68A8});
            table.put(0x2F953, new int [] {0x7956});
            table.put(0x1EA4, new int [] {0x0041, 0x0302, 0x0301});
            table.put(0xF9E1, new int [] {0x674E});
            table.put(0x2F952, new int [] {0x25626});
            table.put(0x1EA3, new int [] {0x0061, 0x0309});
            table.put(0xF9E0, new int [] {0x6613});
            table.put(0x2F951, new int [] {0x40E3});
            table.put(0x1EA2, new int [] {0x0041, 0x0309});
            table.put(0x2F950, new int [] {0x78CC});
            table.put(0x04C2, new int [] {0x0436, 0x0306});
            table.put(0x1EA1, new int [] {0x0061, 0x0323});
            table.put(0x04C1, new int [] {0x0416, 0x0306});
            table.put(0x1EA0, new int [] {0x0041, 0x0323});
            table.put(0xF9DF, new int [] {0x5C65});
            table.put(0xF9DE, new int [] {0x540F});
            table.put(0x2F94F, new int [] {0x788C});
            table.put(0xF9DD, new int [] {0x5229});
            table.put(0x2F94E, new int [] {0x784E});
            table.put(0xF9DC, new int [] {0x9686});
            table.put(0x2F94D, new int [] {0x2541D});
            table.put(0xF9DB, new int [] {0x7387});
            table.put(0x2F94C, new int [] {0x4096});
            table.put(0xF9DA, new int [] {0x6817});
            table.put(0x2F94B, new int [] {0x4046});
            table.put(0x2F94A, new int [] {0x778B});
            table.put(0xF9D9, new int [] {0x6144});
            table.put(0xF9D8, new int [] {0x5F8B});
            table.put(0x2F949, new int [] {0x4039});
            table.put(0xF9D7, new int [] {0x8F2A});
            table.put(0x2F948, new int [] {0x774A});
            table.put(0xF9D6, new int [] {0x6DEA});
            table.put(0x2F947, new int [] {0x771F});
            table.put(0xF9D5, new int [] {0x5D19});
            table.put(0x2F946, new int [] {0x771F});
            table.put(0xF9D4, new int [] {0x502B});
            table.put(0x2F945, new int [] {0x771E});
            table.put(0xF9D3, new int [] {0x9678});
            table.put(0x2F944, new int [] {0x25133});
            table.put(0xF9D2, new int [] {0x622E});
            table.put(0x2F943, new int [] {0x25119});
            table.put(0xF9D1, new int [] {0x516D});
            table.put(0x2F942, new int [] {0x250F2});
            table.put(0xF9D0, new int [] {0x985E});
            table.put(0x2F941, new int [] {0x250F3});
            table.put(0x2F940, new int [] {0x76F4});
            table.put(0xF9CF, new int [] {0x7D10});
            table.put(0xF9CE, new int [] {0x786B});
            table.put(0x2F93F, new int [] {0x4008});
            table.put(0xF9CD, new int [] {0x7559});
            table.put(0x2F93E, new int [] {0x3FFC});
            table.put(0xF9CC, new int [] {0x7409});
            table.put(0x2F93D, new int [] {0x25044});
            table.put(0xF9CB, new int [] {0x6E9C});
            table.put(0x2F93C, new int [] {0x24FB8});
            table.put(0xF9CA, new int [] {0x6D41});
            table.put(0x2F93B, new int [] {0x24FA1});
            table.put(0x2F93A, new int [] {0x7610});
            table.put(0xF9C9, new int [] {0x67F3});
            table.put(0xF9C8, new int [] {0x677B});
            table.put(0x2F939, new int [] {0x2219F});
            table.put(0xF9C7, new int [] {0x5289});
            table.put(0x2F938, new int [] {0x7570});
            table.put(0xF9C6, new int [] {0x962E});
            table.put(0x2F937, new int [] {0x24C92});
            table.put(0xF9C5, new int [] {0x6688});
            table.put(0x2F936, new int [] {0x753E});
            table.put(0xF9C4, new int [] {0x9F8D});
            table.put(0x2F935, new int [] {0x24C36});
            table.put(0xF9C3, new int [] {0x907C});
            table.put(0x2F934, new int [] {0x7524});
            table.put(0xF9C2, new int [] {0x84FC});
            table.put(0x2F933, new int [] {0x3F1B});
            table.put(0xF9C1, new int [] {0x7642});
            table.put(0x2F932, new int [] {0x74CA});
            table.put(0xF9C0, new int [] {0x71CE});
            table.put(0x2F931, new int [] {0x7485});
            table.put(0x2F930, new int [] {0x7471});
            table.put(0xF9BF, new int [] {0x6A02});
            table.put(0xF9BE, new int [] {0x6599});
            table.put(0x2F92F, new int [] {0x745C});
            table.put(0xF9BD, new int [] {0x5C3F});
            table.put(0x2F92E, new int [] {0x7447});
            table.put(0xF9BC, new int [] {0x5BEE});
            table.put(0x2F92D, new int [] {0x3EB8});
            table.put(0xF9BB, new int [] {0x50DA});
            table.put(0x2F92C, new int [] {0x3EB8});
            table.put(0xF9BA, new int [] {0x4E86});
            table.put(0x2F92B, new int [] {0x73A5});
            table.put(0x2F92A, new int [] {0x3EAC});
            table.put(0xF9B9, new int [] {0x60E1});
            table.put(0xF9B8, new int [] {0x96B8});
            table.put(0x2F929, new int [] {0x738B});
            table.put(0xF9B7, new int [] {0x91B4});
            table.put(0x2F928, new int [] {0x737A});
            table.put(0xF9B6, new int [] {0x79AE});
            table.put(0x2F927, new int [] {0x24814});
            table.put(0xF9B5, new int [] {0x4F8B});
            table.put(0x2F926, new int [] {0x24735});
            table.put(0xF9B4, new int [] {0x9818});
            table.put(0x2F925, new int [] {0x7295});
            table.put(0xF9B3, new int [] {0x9748});
            table.put(0x2F924, new int [] {0x7280});
            table.put(0xF9B2, new int [] {0x96F6});
            table.put(0x2F923, new int [] {0x24608});
            table.put(0xF9B1, new int [] {0x9234});
            table.put(0x2F922, new int [] {0x7250});
            table.put(0xF9B0, new int [] {0x8046});
            table.put(0x2F921, new int [] {0x7235});
            table.put(0x2F920, new int [] {0x7228});
            table.put(0xF9AF, new int [] {0x7F9A});
            table.put(0xF9AE, new int [] {0x7469});
            table.put(0x2F91F, new int [] {0x243AB});
            table.put(0xF9AD, new int [] {0x73B2});
            table.put(0x2F91E, new int [] {0x719C});
            table.put(0xF9AC, new int [] {0x601C});
            table.put(0x2F91D, new int [] {0x24263});
            table.put(0xF9AB, new int [] {0x5DBA});
            table.put(0x2F91C, new int [] {0x7145});
            table.put(0xF9AA, new int [] {0x5BE7});
            table.put(0x2F91B, new int [] {0x20525});
            table.put(0x2F91A, new int [] {0x70AD});
            table.put(0xF9A9, new int [] {0x56F9});
            table.put(0xF9A8, new int [] {0x4EE4});
            table.put(0x2F919, new int [] {0x7077});
            table.put(0xF9A7, new int [] {0x7375});
            table.put(0x2F918, new int [] {0x707D});
            table.put(0xF9A6, new int [] {0x7C3E});
            table.put(0x2F917, new int [] {0x704A});
            table.put(0xF9A5, new int [] {0x6BAE});
            table.put(0x2F916, new int [] {0x3D96});
            table.put(0xF9A4, new int [] {0x637B});
            table.put(0x2F915, new int [] {0x701B});
            table.put(0xF9A3, new int [] {0x5FF5});
            table.put(0x2F914, new int [] {0x701E});
            table.put(0xF9A2, new int [] {0x5EC9});
            table.put(0x2F913, new int [] {0x7039});
            table.put(0xF9A1, new int [] {0x8AAA});
            table.put(0x2F912, new int [] {0x6FC6});
            table.put(0xF9A0, new int [] {0x88C2});
            table.put(0x2F911, new int [] {0x23F8E});
            table.put(0x2F910, new int [] {0x23F5E});
            table.put(0x2001, new int [] {0x2003});
            table.put(0x2000, new int [] {0x2002});
            table.put(0x2F90F, new int [] {0x6F6E});
            table.put(0x2F90E, new int [] {0x6DF9});
            table.put(0x2F90D, new int [] {0x23ED1});
            table.put(0x2F90C, new int [] {0x6EC7});
            table.put(0x2F90B, new int [] {0x6ECB});
            table.put(0x2F90A, new int [] {0x3D33});
            table.put(0x2F909, new int [] {0x6E6E});
            table.put(0x2F908, new int [] {0x6E2F});
            table.put(0x2F907, new int [] {0x6D34});
            table.put(0x2F906, new int [] {0x23D1E});
            table.put(0x2F905, new int [] {0x6D85});
            table.put(0x2F904, new int [] {0x6D78});
            table.put(0x2F903, new int [] {0x6D69});
            table.put(0x2F902, new int [] {0x6D41});
            table.put(0x2F901, new int [] {0x6D77});
            table.put(0x2F900, new int [] {0x6D3E});
            table.put(0x017E, new int [] {0x007A, 0x030C});
            table.put(0x017D, new int [] {0x005A, 0x030C});
            table.put(0x017C, new int [] {0x007A, 0x0307});
            table.put(0x017B, new int [] {0x005A, 0x0307});
            table.put(0x017A, new int [] {0x007A, 0x0301});
            table.put(0x0179, new int [] {0x005A, 0x0301});
            table.put(0x0178, new int [] {0x0059, 0x0308});
            table.put(0x0177, new int [] {0x0079, 0x0302});
            table.put(0x0176, new int [] {0x0059, 0x0302});
            table.put(0x0175, new int [] {0x0077, 0x0302});
            table.put(0x0174, new int [] {0x0057, 0x0302});
            table.put(0x0173, new int [] {0x0075, 0x0328});
            table.put(0x0172, new int [] {0x0055, 0x0328});
            table.put(0x0171, new int [] {0x0075, 0x030B});
            table.put(0x0170, new int [] {0x0055, 0x030B});
            table.put(0x016F, new int [] {0x0075, 0x030A});
            table.put(0x016E, new int [] {0x0055, 0x030A});
            table.put(0x016D, new int [] {0x0075, 0x0306});
            table.put(0x016C, new int [] {0x0055, 0x0306});
            table.put(0x016B, new int [] {0x0075, 0x0304});
            table.put(0x016A, new int [] {0x0055, 0x0304});
            table.put(0x0A5E, new int [] {0x0A2B, 0x0A3C});
            table.put(0x0169, new int [] {0x0075, 0x0303});
            table.put(0x0168, new int [] {0x0055, 0x0303});
            table.put(0x0A5B, new int [] {0x0A1C, 0x0A3C});
            table.put(0x0A5A, new int [] {0x0A17, 0x0A3C});
            table.put(0x0165, new int [] {0x0074, 0x030C});
            table.put(0x0164, new int [] {0x0054, 0x030C});
            table.put(0x0163, new int [] {0x0074, 0x0327});
            table.put(0x0162, new int [] {0x0054, 0x0327});
            table.put(0x0161, new int [] {0x0073, 0x030C});
            table.put(0x0160, new int [] {0x0053, 0x030C});
            table.put(0x0A59, new int [] {0x0A16, 0x0A3C});
            table.put(0x015F, new int [] {0x0073, 0x0327});
            table.put(0x015E, new int [] {0x0053, 0x0327});
            table.put(0x015D, new int [] {0x0073, 0x0302});
            table.put(0x015C, new int [] {0x0053, 0x0302});
            table.put(0x015B, new int [] {0x0073, 0x0301});
            table.put(0x015A, new int [] {0x0053, 0x0301});
            table.put(0x1E9B, new int [] {0x017F, 0x0307});
            table.put(0x0159, new int [] {0x0072, 0x030C});
            table.put(0x0158, new int [] {0x0052, 0x030C});
            table.put(0x1E99, new int [] {0x0079, 0x030A});
            table.put(0x232A, new int [] {0x3009});
            table.put(0x0157, new int [] {0x0072, 0x0327});
            table.put(0x1E98, new int [] {0x0077, 0x030A});
            table.put(0x0156, new int [] {0x0052, 0x0327});
            table.put(0x1E97, new int [] {0x0074, 0x0308});
            table.put(0x0155, new int [] {0x0072, 0x0301});
            table.put(0x1E96, new int [] {0x0068, 0x0331});
            table.put(0x0154, new int [] {0x0052, 0x0301});
            table.put(0x1E95, new int [] {0x007A, 0x0331});
            table.put(0x1E94, new int [] {0x005A, 0x0331});
            table.put(0x1E93, new int [] {0x007A, 0x0323});
            table.put(0x0151, new int [] {0x006F, 0x030B});
            table.put(0x1E92, new int [] {0x005A, 0x0323});
            table.put(0x0150, new int [] {0x004F, 0x030B});
            table.put(0x1E91, new int [] {0x007A, 0x0302});
            table.put(0x2329, new int [] {0x3008});
            table.put(0x1E90, new int [] {0x005A, 0x0302});
            table.put(0x014F, new int [] {0x006F, 0x0306});
            table.put(0x014E, new int [] {0x004F, 0x0306});
            table.put(0x1E8F, new int [] {0x0079, 0x0307});
            table.put(0x014D, new int [] {0x006F, 0x0304});
            table.put(0x1E8E, new int [] {0x0059, 0x0307});
            table.put(0x014C, new int [] {0x004F, 0x0304});
            table.put(0x1E8D, new int [] {0x0078, 0x0308});
            table.put(0x1E8C, new int [] {0x0058, 0x0308});
            table.put(0x1E8B, new int [] {0x0078, 0x0307});
            table.put(0x1E8A, new int [] {0x0058, 0x0307});
            table.put(0x0148, new int [] {0x006E, 0x030C});
            table.put(0x1E89, new int [] {0x0077, 0x0323});
            table.put(0x0147, new int [] {0x004E, 0x030C});
            table.put(0x1E88, new int [] {0x0057, 0x0323});
            table.put(0x0146, new int [] {0x006E, 0x0327});
            table.put(0x1E87, new int [] {0x0077, 0x0307});
            table.put(0x0145, new int [] {0x004E, 0x0327});
            table.put(0x1E86, new int [] {0x0057, 0x0307});
            table.put(0x0144, new int [] {0x006E, 0x0301});
            table.put(0x1E85, new int [] {0x0077, 0x0308});
            table.put(0x0143, new int [] {0x004E, 0x0301});
            table.put(0x1E84, new int [] {0x0057, 0x0308});
            table.put(0x1E83, new int [] {0x0077, 0x0301});
            table.put(0x1E82, new int [] {0x0057, 0x0301});
            table.put(0x1E81, new int [] {0x0077, 0x0300});
            table.put(0x1E80, new int [] {0x0057, 0x0300});
            table.put(0x0A36, new int [] {0x0A38, 0x0A3C});
            table.put(0x0A33, new int [] {0x0A32, 0x0A3C});
            table.put(0x013E, new int [] {0x006C, 0x030C});
            table.put(0x1E7F, new int [] {0x0076, 0x0323});
            table.put(0x013D, new int [] {0x004C, 0x030C});
            table.put(0x1E7E, new int [] {0x0056, 0x0323});
            table.put(0x013C, new int [] {0x006C, 0x0327});
            table.put(0x1E7D, new int [] {0x0076, 0x0303});
            table.put(0x013B, new int [] {0x004C, 0x0327});
            table.put(0x1E7C, new int [] {0x0056, 0x0303});
            table.put(0x013A, new int [] {0x006C, 0x0301});
            table.put(0x1E7B, new int [] {0x0075, 0x0304, 0x0308});
            table.put(0x1E7A, new int [] {0x0055, 0x0304, 0x0308});
            table.put(0x0139, new int [] {0x004C, 0x0301});
            table.put(0x1E79, new int [] {0x0075, 0x0303, 0x0301});
            table.put(0x0137, new int [] {0x006B, 0x0327});
            table.put(0x1E78, new int [] {0x0055, 0x0303, 0x0301});
            table.put(0x0136, new int [] {0x004B, 0x0327});
            table.put(0x1E77, new int [] {0x0075, 0x032D});
            table.put(0x0135, new int [] {0x006A, 0x0302});
            table.put(0x1E76, new int [] {0x0055, 0x032D});
            table.put(0x0134, new int [] {0x004A, 0x0302});
            table.put(0x1E75, new int [] {0x0075, 0x0330});
            table.put(0x1E74, new int [] {0x0055, 0x0330});
            table.put(0x1E73, new int [] {0x0075, 0x0324});
            table.put(0x1E72, new int [] {0x0055, 0x0324});
            table.put(0x0130, new int [] {0x0049, 0x0307});
            table.put(0x1E71, new int [] {0x0074, 0x032D});
            table.put(0x1E70, new int [] {0x0054, 0x032D});
            table.put(0x012F, new int [] {0x0069, 0x0328});
            table.put(0x012E, new int [] {0x0049, 0x0328});
            table.put(0x1E6F, new int [] {0x0074, 0x0331});
            table.put(0x012D, new int [] {0x0069, 0x0306});
            table.put(0x1E6E, new int [] {0x0054, 0x0331});
            table.put(0x012C, new int [] {0x0049, 0x0306});
            table.put(0x1E6D, new int [] {0x0074, 0x0323});
            table.put(0x012B, new int [] {0x0069, 0x0304});
            table.put(0x1E6C, new int [] {0x0054, 0x0323});
            table.put(0x012A, new int [] {0x0049, 0x0304});
            table.put(0x1E6B, new int [] {0x0074, 0x0307});
            table.put(0x1E6A, new int [] {0x0054, 0x0307});
            table.put(0x0129, new int [] {0x0069, 0x0303});
            table.put(0x0128, new int [] {0x0049, 0x0303});
            table.put(0x1E69, new int [] {0x0073, 0x0323, 0x0307});
            table.put(0x1E68, new int [] {0x0053, 0x0323, 0x0307});
            table.put(0x1E67, new int [] {0x0073, 0x030C, 0x0307});
            table.put(0x0125, new int [] {0x0068, 0x0302});
            table.put(0x1E66, new int [] {0x0053, 0x030C, 0x0307});
            table.put(0x0124, new int [] {0x0048, 0x0302});
            table.put(0x1E65, new int [] {0x0073, 0x0301, 0x0307});
            table.put(0x0123, new int [] {0x0067, 0x0327});
            table.put(0x1E64, new int [] {0x0053, 0x0301, 0x0307});
            table.put(0x0122, new int [] {0x0047, 0x0327});
            table.put(0x1E63, new int [] {0x0073, 0x0323});
            table.put(0x0121, new int [] {0x0067, 0x0307});
            table.put(0x1E62, new int [] {0x0053, 0x0323});
            table.put(0x0120, new int [] {0x0047, 0x0307});
            table.put(0x1E61, new int [] {0x0073, 0x0307});
            table.put(0x1E60, new int [] {0x0053, 0x0307});
            table.put(0x30FE, new int [] {0x30FD, 0x3099});
            table.put(0xF99F, new int [] {0x70C8});
            table.put(0xF99E, new int [] {0x54BD});
            table.put(0x011F, new int [] {0x0067, 0x0306});
            table.put(0xF99D, new int [] {0x52A3});
            table.put(0x011E, new int [] {0x0047, 0x0306});
            table.put(0x1E5F, new int [] {0x0072, 0x0331});
            table.put(0x30FA, new int [] {0x30F2, 0x3099});
            table.put(0xF99C, new int [] {0x5217});
            table.put(0x011D, new int [] {0x0067, 0x0302});
            table.put(0x1E5E, new int [] {0x0052, 0x0331});
            table.put(0xF99B, new int [] {0x934A});
            table.put(0x011C, new int [] {0x0047, 0x0302});
            table.put(0x1E5D, new int [] {0x0072, 0x0323, 0x0304});
            table.put(0xF99A, new int [] {0x9023});
            table.put(0x011B, new int [] {0x0065, 0x030C});
            table.put(0x1E5C, new int [] {0x0052, 0x0323, 0x0304});
            table.put(0x011A, new int [] {0x0045, 0x030C});
            table.put(0x1E5B, new int [] {0x0072, 0x0323});
            table.put(0x1E5A, new int [] {0x0052, 0x0323});
            table.put(0x30F9, new int [] {0x30F1, 0x3099});
            table.put(0x30F8, new int [] {0x30F0, 0x3099});
            table.put(0x30F7, new int [] {0x30EF, 0x3099});
            table.put(0xF999, new int [] {0x84EE});
            table.put(0xF998, new int [] {0x8F26});
            table.put(0x0119, new int [] {0x0065, 0x0328});
            table.put(0xF997, new int [] {0x806F});
            table.put(0x0118, new int [] {0x0045, 0x0328});
            table.put(0x1E59, new int [] {0x0072, 0x0307});
            table.put(0x30F4, new int [] {0x30A6, 0x3099});
            table.put(0xF996, new int [] {0x7DF4});
            table.put(0x0117, new int [] {0x0065, 0x0307});
            table.put(0x1E58, new int [] {0x0052, 0x0307});
            table.put(0xF995, new int [] {0x79CA});
            table.put(0x0116, new int [] {0x0045, 0x0307});
            table.put(0x1E57, new int [] {0x0070, 0x0307});
            table.put(0xF994, new int [] {0x7489});
            table.put(0xF993, new int [] {0x7149});
            table.put(0x0115, new int [] {0x0065, 0x0306});
            table.put(0x0477, new int [] {0x0475, 0x030F});
            table.put(0x1E56, new int [] {0x0050, 0x0307});
            table.put(0xF992, new int [] {0x6F23});
            table.put(0x1E55, new int [] {0x0070, 0x0301});
            table.put(0x0476, new int [] {0x0474, 0x030F});
            table.put(0x0114, new int [] {0x0045, 0x0306});
            table.put(0xF991, new int [] {0x649A});
            table.put(0x1E54, new int [] {0x0050, 0x0301});
            table.put(0x0113, new int [] {0x0065, 0x0304});
            table.put(0xF990, new int [] {0x6200});
            table.put(0x1E53, new int [] {0x006F, 0x0304, 0x0301});
            table.put(0x0112, new int [] {0x0045, 0x0304});
            table.put(0x1E52, new int [] {0x004F, 0x0304, 0x0301});
            table.put(0x1E51, new int [] {0x006F, 0x0304, 0x0300});
            table.put(0x1E50, new int [] {0x004F, 0x0304, 0x0300});
            table.put(0xF98F, new int [] {0x6190});
            table.put(0xF98E, new int [] {0x5E74});
            table.put(0xF98D, new int [] {0x8F62});
            table.put(0x010F, new int [] {0x0064, 0x030C});
            table.put(0xF98C, new int [] {0x6B77});
            table.put(0x1E4F, new int [] {0x006F, 0x0303, 0x0308});
            table.put(0x010E, new int [] {0x0044, 0x030C});
            table.put(0xF98B, new int [] {0x66C6});
            table.put(0x1E4E, new int [] {0x004F, 0x0303, 0x0308});
            table.put(0x010D, new int [] {0x0063, 0x030C});
            table.put(0xF98A, new int [] {0x529B});
            table.put(0x1E4D, new int [] {0x006F, 0x0303, 0x0301});
            table.put(0x010C, new int [] {0x0043, 0x030C});
            table.put(0x1E4C, new int [] {0x004F, 0x0303, 0x0301});
            table.put(0x010B, new int [] {0x0063, 0x0307});
            table.put(0x1E4B, new int [] {0x006E, 0x032D});
            table.put(0x010A, new int [] {0x0043, 0x0307});
            table.put(0x1E4A, new int [] {0x004E, 0x032D});
            table.put(0xF989, new int [] {0x9ECE});
            table.put(0xF988, new int [] {0x9E97});
            table.put(0xF987, new int [] {0x9A6A});
            table.put(0x0109, new int [] {0x0063, 0x0302});
            table.put(0xF986, new int [] {0x95AD});
            table.put(0x1E49, new int [] {0x006E, 0x0331});
            table.put(0x0108, new int [] {0x0043, 0x0302});
            table.put(0xF985, new int [] {0x792A});
            table.put(0x1E48, new int [] {0x004E, 0x0331});
            table.put(0x0107, new int [] {0x0063, 0x0301});
            table.put(0xF984, new int [] {0x6FFE});
            table.put(0x1E47, new int [] {0x006E, 0x0323});
            table.put(0x0106, new int [] {0x0043, 0x0301});
            table.put(0xF983, new int [] {0x65C5});
            table.put(0x1E46, new int [] {0x004E, 0x0323});
            table.put(0x0105, new int [] {0x0061, 0x0328});
            table.put(0xF982, new int [] {0x5EEC});
            table.put(0x1E45, new int [] {0x006E, 0x0307});
            table.put(0x0104, new int [] {0x0041, 0x0328});
            table.put(0xF981, new int [] {0x5973});
            table.put(0x1E44, new int [] {0x004E, 0x0307});
            table.put(0x0103, new int [] {0x0061, 0x0306});
            table.put(0xF980, new int [] {0x5442});
            table.put(0x1E43, new int [] {0x006D, 0x0323});
            table.put(0x0102, new int [] {0x0041, 0x0306});
            table.put(0x1E42, new int [] {0x004D, 0x0323});
            table.put(0x0101, new int [] {0x0061, 0x0304});
            table.put(0x1E41, new int [] {0x006D, 0x0307});
            table.put(0x0100, new int [] {0x0041, 0x0304});
            table.put(0x1E40, new int [] {0x004D, 0x0307});
            table.put(0xF97F, new int [] {0x52F5});
            table.put(0x30DD, new int [] {0x30DB, 0x309A});
            table.put(0xF97E, new int [] {0x91CF});
            table.put(0x30DC, new int [] {0x30DB, 0x3099});
            table.put(0xF97D, new int [] {0x8AD2});
            table.put(0x2F8FF, new int [] {0x6D16});
            table.put(0xF97C, new int [] {0x826F});
            table.put(0x30DA, new int [] {0x30D8, 0x309A});
            table.put(0x1E3F, new int [] {0x006D, 0x0301});
            table.put(0x2F8FE, new int [] {0x6C67});
            table.put(0xF97B, new int [] {0x7CE7});
            table.put(0x1E3E, new int [] {0x004D, 0x0301});
            table.put(0x2F8FD, new int [] {0x6CCD});
            table.put(0xF97A, new int [] {0x6881});
            table.put(0x1E3D, new int [] {0x006C, 0x032D});
            table.put(0x045E, new int [] {0x0443, 0x0306});
            table.put(0x2F8FC, new int [] {0x6CBF});
            table.put(0x1E3C, new int [] {0x004C, 0x032D});
            table.put(0x045D, new int [] {0x0438, 0x0300});
            table.put(0x2F8FB, new int [] {0x23CBC});
            table.put(0x1E3B, new int [] {0x006C, 0x0331});
            table.put(0x045C, new int [] {0x043A, 0x0301});
            table.put(0x2F8FA, new int [] {0x6C4E});
            table.put(0x1E3A, new int [] {0x004C, 0x0331});
            table.put(0x30D9, new int [] {0x30D8, 0x3099});
            table.put(0xF979, new int [] {0x51C9});
            table.put(0x30D7, new int [] {0x30D5, 0x309A});
            table.put(0xF978, new int [] {0x5169});
            table.put(0x30D6, new int [] {0x30D5, 0x3099});
            table.put(0xF977, new int [] {0x4EAE});
            table.put(0x2F8F9, new int [] {0x23AFA});
            table.put(0xF976, new int [] {0x7565});
            table.put(0x30D4, new int [] {0x30D2, 0x309A});
            table.put(0x1E39, new int [] {0x006C, 0x0323, 0x0304});
            table.put(0x2F8F8, new int [] {0x21D0B});
            table.put(0xF975, new int [] {0x63A0});
            table.put(0x30D3, new int [] {0x30D2, 0x3099});
            table.put(0x1E38, new int [] {0x004C, 0x0323, 0x0304});
            table.put(0x0D4C, new int [] {0x0D46, 0x0D57});
            table.put(0x2F8F7, new int [] {0x23A8D});
            table.put(0xF974, new int [] {0x82E5});
            table.put(0x1E37, new int [] {0x006C, 0x0323});
            table.put(0x0D4B, new int [] {0x0D47, 0x0D3E});
            table.put(0x2F8F6, new int [] {0x6BBB});
            table.put(0xF973, new int [] {0x62FE});
            table.put(0x30D1, new int [] {0x30CF, 0x309A});
            table.put(0x1E36, new int [] {0x004C, 0x0323});
            table.put(0x0D4A, new int [] {0x0D46, 0x0D3E});
            table.put(0x0457, new int [] {0x0456, 0x0308});
            table.put(0x2F8F5, new int [] {0x6BBA});
            table.put(0xF972, new int [] {0x6C88});
            table.put(0x30D0, new int [] {0x30CF, 0x3099});
            table.put(0x1E35, new int [] {0x006B, 0x0331});
            table.put(0x2F8F4, new int [] {0x6B9F});
            table.put(0xF971, new int [] {0x8FB0});
            table.put(0x1E34, new int [] {0x004B, 0x0331});
            table.put(0x2F8F3, new int [] {0x6B72});
            table.put(0xF970, new int [] {0x6BBA});
            table.put(0x1E33, new int [] {0x006B, 0x0323});
            table.put(0x2F8F2, new int [] {0x3C4E});
            table.put(0x1E32, new int [] {0x004B, 0x0323});
            table.put(0x0453, new int [] {0x0433, 0x0301});
            table.put(0x2F8F1, new int [] {0x6B54});
            table.put(0x1E31, new int [] {0x006B, 0x0301});
            table.put(0x2F8F0, new int [] {0x238A7});
            table.put(0x1E30, new int [] {0x004B, 0x0301});
            table.put(0x0451, new int [] {0x0435, 0x0308});
            table.put(0x0450, new int [] {0x0435, 0x0300});
            table.put(0xF96F, new int [] {0x8AAA});
            table.put(0xF96E, new int [] {0x8449});
            table.put(0xF96D, new int [] {0x7701});
            table.put(0x2F8EF, new int [] {0x6B21});
            table.put(0xF96C, new int [] {0x585E});
            table.put(0x1E2F, new int [] {0x0069, 0x0308, 0x0301});
            table.put(0x2F8EE, new int [] {0x3C18});
            table.put(0xF96B, new int [] {0x53C3});
            table.put(0x1E2E, new int [] {0x0049, 0x0308, 0x0301});
            table.put(0x2F8ED, new int [] {0x6ADB});
            table.put(0xF96A, new int [] {0x7D22});
            table.put(0x1E2D, new int [] {0x0069, 0x0330});
            table.put(0x2F8EC, new int [] {0x236A3});
            table.put(0x1E2C, new int [] {0x0049, 0x0330});
            table.put(0x2F8EB, new int [] {0x6AA8});
            table.put(0x1E2B, new int [] {0x0068, 0x032E});
            table.put(0x2F8EA, new int [] {0x69EA});
            table.put(0x1E2A, new int [] {0x0048, 0x032E});
            table.put(0x30C9, new int [] {0x30C8, 0x3099});
            table.put(0xF969, new int [] {0x6578});
            table.put(0x30C7, new int [] {0x30C6, 0x3099});
            table.put(0xF968, new int [] {0x6CCC});
            table.put(0xF967, new int [] {0x4E0D});
            table.put(0x30C5, new int [] {0x30C4, 0x3099});
            table.put(0x2F8E9, new int [] {0x69A3});
            table.put(0xF966, new int [] {0x5FA9});
            table.put(0x1E29, new int [] {0x0068, 0x0327});
            table.put(0x2F8E8, new int [] {0x6942});
            table.put(0xF965, new int [] {0x4FBF});
            table.put(0x1E28, new int [] {0x0048, 0x0327});
            table.put(0x2F8E7, new int [] {0x3B9D});
            table.put(0xF964, new int [] {0x78FB});
            table.put(0x30C2, new int [] {0x30C1, 0x3099});
            table.put(0x1E27, new int [] {0x0068, 0x0308});
            table.put(0x2F8E6, new int [] {0x6914});
            table.put(0xF963, new int [] {0x5317});
            table.put(0x1E26, new int [] {0x0048, 0x0308});
            table.put(0x2F8E5, new int [] {0x681F});
            table.put(0xF962, new int [] {0x7570});
            table.put(0x30C0, new int [] {0x30BF, 0x3099});
            table.put(0x1E25, new int [] {0x0068, 0x0323});
            table.put(0x2F8E4, new int [] {0x688E});
            table.put(0xF961, new int [] {0x7387});
            table.put(0x1E24, new int [] {0x0048, 0x0323});
            table.put(0x2F8E3, new int [] {0x2346D});
            table.put(0xF960, new int [] {0x6012});
            table.put(0x1E23, new int [] {0x0068, 0x0307});
            table.put(0x2F8E2, new int [] {0x6885});
            table.put(0x1E22, new int [] {0x0048, 0x0307});
            table.put(0x2F8E1, new int [] {0x6852});
            table.put(0x1E21, new int [] {0x0067, 0x0304});
            table.put(0x2F8E0, new int [] {0x6785});
            table.put(0x1E20, new int [] {0x0047, 0x0304});
            table.put(0x30BE, new int [] {0x30BD, 0x3099});
            table.put(0xF95F, new int [] {0x5BE7});
            table.put(0xF95E, new int [] {0x4E39});
            table.put(0x30BC, new int [] {0x30BB, 0x3099});
            table.put(0xF95D, new int [] {0x8AFE});
            table.put(0x2F8DF, new int [] {0x67FA});
            table.put(0xF95C, new int [] {0x6A02});
            table.put(0x30BA, new int [] {0x30B9, 0x3099});
            table.put(0x1E1F, new int [] {0x0066, 0x0307});
            table.put(0x2F8DE, new int [] {0x3B49});
            table.put(0xF95B, new int [] {0x62CF});
            table.put(0x1E1E, new int [] {0x0046, 0x0307});
            table.put(0x2F8DD, new int [] {0x233C3});
            table.put(0xF95A, new int [] {0x8B80});
            table.put(0x1E1D, new int [] {0x0065, 0x0327, 0x0306});
            table.put(0x2F8DC, new int [] {0x6753});
            table.put(0x1E1C, new int [] {0x0045, 0x0327, 0x0306});
            table.put(0x2F8DB, new int [] {0x675E});
            table.put(0x1E1B, new int [] {0x0065, 0x0330});
            table.put(0x2F8DA, new int [] {0x6721});
            table.put(0x1E1A, new int [] {0x0045, 0x0330});
            table.put(0x30B8, new int [] {0x30B7, 0x3099});
            table.put(0xF959, new int [] {0x9675});
            table.put(0xF958, new int [] {0x83F1});
            table.put(0x30B6, new int [] {0x30B5, 0x3099});
            table.put(0xF957, new int [] {0x7DBE});
            table.put(0x2F8D9, new int [] {0x671B});
            table.put(0xF956, new int [] {0x7A1C});
            table.put(0x30B4, new int [] {0x30B3, 0x3099});
            table.put(0x1E19, new int [] {0x0065, 0x032D});
            table.put(0x2F8D8, new int [] {0x6717});
            table.put(0xF955, new int [] {0x51CC});
            table.put(0x1E18, new int [] {0x0045, 0x032D});
            table.put(0x0439, new int [] {0x0438, 0x0306});
            table.put(0x2F8D7, new int [] {0x43D9});
            table.put(0xF954, new int [] {0x51DC});
            table.put(0x30B2, new int [] {0x30B1, 0x3099});
            table.put(0x1E17, new int [] {0x0065, 0x0304, 0x0301});
            table.put(0x2F8D6, new int [] {0x80AD});
            table.put(0xF953, new int [] {0x808B});
            table.put(0x1E16, new int [] {0x0045, 0x0304, 0x0301});
            table.put(0x2F8D5, new int [] {0x669C});
            table.put(0xF952, new int [] {0x52D2});
            table.put(0x30B0, new int [] {0x30AF, 0x3099});
            table.put(0x1E15, new int [] {0x0065, 0x0304, 0x0300});
            table.put(0x2F8D4, new int [] {0x6700});
            table.put(0xF951, new int [] {0x964B});
            table.put(0x1E14, new int [] {0x0045, 0x0304, 0x0300});
            table.put(0x2F8D3, new int [] {0x5195});
            table.put(0xF950, new int [] {0x7E37});
            table.put(0x1E13, new int [] {0x0064, 0x032D});
            table.put(0x2F8D2, new int [] {0x5192});
            table.put(0x1E12, new int [] {0x0044, 0x032D});
            table.put(0x2F8D1, new int [] {0x3AE4});
            table.put(0x1E11, new int [] {0x0064, 0x0327});
            table.put(0x2F8D0, new int [] {0x3B08});
            table.put(0x1E10, new int [] {0x0044, 0x0327});
            table.put(0x30AE, new int [] {0x30AD, 0x3099});
            table.put(0xF94F, new int [] {0x7D2F});
            table.put(0xF94E, new int [] {0x6F0F});
            table.put(0x30AC, new int [] {0x30AB, 0x3099});
            table.put(0xF94D, new int [] {0x6DDA});
            table.put(0x2F8CF, new int [] {0x6691});
            table.put(0xF94C, new int [] {0x6A13});
            table.put(0x1E0F, new int [] {0x0064, 0x0331});
            table.put(0x2F8CE, new int [] {0x3B19});
            table.put(0xF94B, new int [] {0x5C62});
            table.put(0x1E0E, new int [] {0x0044, 0x0331});
            table.put(0x2F8CD, new int [] {0x6649});
            table.put(0xF94A, new int [] {0x58D8});
            table.put(0x1E0D, new int [] {0x0064, 0x0323});
            table.put(0x2F8CC, new int [] {0x66F8});
            table.put(0x1E0C, new int [] {0x0044, 0x0323});
            table.put(0x2F8CB, new int [] {0x65E3});
            table.put(0x1E0B, new int [] {0x0064, 0x0307});
            table.put(0x2F8CA, new int [] {0x2300A});
            table.put(0x1E0A, new int [] {0x0044, 0x0307});
            table.put(0xF949, new int [] {0x96F7});
            table.put(0xF948, new int [] {0x8CC2});
            table.put(0xF947, new int [] {0x78CA});
            table.put(0x2F8C9, new int [] {0x656C});
            table.put(0xF946, new int [] {0x7262});
            table.put(0x1E09, new int [] {0x0063, 0x0327, 0x0301});
            table.put(0x2F8C8, new int [] {0x654F});
            table.put(0xF945, new int [] {0x807E});
            table.put(0x1E08, new int [] {0x0043, 0x0327, 0x0301});
            table.put(0x2F8C7, new int [] {0x3A6C});
            table.put(0xF944, new int [] {0x7C60});
            table.put(0x1E07, new int [] {0x0062, 0x0331});
            table.put(0x2F8C6, new int [] {0x6477});
            table.put(0xF943, new int [] {0x5F04});
            table.put(0x1E06, new int [] {0x0042, 0x0331});
            table.put(0x2F8C5, new int [] {0x649D});
            table.put(0xF942, new int [] {0x58DF});
            table.put(0x1E05, new int [] {0x0062, 0x0323});
            table.put(0x2F8C4, new int [] {0x647E});
            table.put(0xF941, new int [] {0x8AD6});
            table.put(0x1E04, new int [] {0x0042, 0x0323});
            table.put(0x2F8C3, new int [] {0x6469});
            table.put(0xF940, new int [] {0x9E7F});
            table.put(0x1E03, new int [] {0x0062, 0x0307});
            table.put(0x2F8C2, new int [] {0x3A2E});
            table.put(0x1E02, new int [] {0x0042, 0x0307});
            table.put(0x2F8C1, new int [] {0x63A9});
            table.put(0x1E01, new int [] {0x0061, 0x0325});
            table.put(0x2F8C0, new int [] {0x63C5});
            table.put(0x1E00, new int [] {0x0041, 0x0325});
            table.put(0xF93F, new int [] {0x9304});
            table.put(0xF93E, new int [] {0x83C9});
            table.put(0xF93D, new int [] {0x7DA0});
            table.put(0x2F8BF, new int [] {0x6422});
            table.put(0xF93C, new int [] {0x797F});
            table.put(0x2F8BE, new int [] {0x22BF1});
            table.put(0xF93B, new int [] {0x788C});
            table.put(0x2F8BD, new int [] {0x63E4});
            table.put(0xF93A, new int [] {0x9DFA});
            table.put(0x2F8BC, new int [] {0x6383});
            table.put(0x2F8BB, new int [] {0x6368});
            table.put(0x2F8BA, new int [] {0x62FC});
            table.put(0xF939, new int [] {0x9B6F});
            table.put(0xF938, new int [] {0x9732});
            table.put(0xF937, new int [] {0x8DEF});
            table.put(0x2F8B9, new int [] {0x633D});
            table.put(0xF936, new int [] {0x865C});
            table.put(0x2F8B8, new int [] {0x22B0C});
            table.put(0xF935, new int [] {0x8606});
            table.put(0x0419, new int [] {0x0418, 0x0306});
            table.put(0x2F8B7, new int [] {0x6350});
            table.put(0xF934, new int [] {0x8001});
            table.put(0x2F8B6, new int [] {0x62D4});
            table.put(0xF933, new int [] {0x76E7});
            table.put(0x2F8B5, new int [] {0x62B1});
            table.put(0xF932, new int [] {0x7210});
            table.put(0x2F8B4, new int [] {0x625D});
            table.put(0xF931, new int [] {0x6AD3});
            table.put(0x2F8B3, new int [] {0x621B});
            table.put(0xF930, new int [] {0x64C4});
            table.put(0x2F8B2, new int [] {0x6210});
            table.put(0x2F8B1, new int [] {0x61F6});
            table.put(0x2F8B0, new int [] {0x61F2});
            table.put(0xF92F, new int [] {0x52DE});
            table.put(0xF92E, new int [] {0x51B7});
            table.put(0xF92D, new int [] {0x4F86});
            table.put(0x2F8AF, new int [] {0x61DE});
            table.put(0xF92C, new int [] {0x90CE});
            table.put(0x2F8AE, new int [] {0x61AF});
            table.put(0xF92B, new int [] {0x72FC});
            table.put(0x2F8AD, new int [] {0x61A4});
            table.put(0xF92A, new int [] {0x6D6A});
            table.put(0x040E, new int [] {0x0423, 0x0306});
            table.put(0x2F8AC, new int [] {0x61B2});
            table.put(0x040D, new int [] {0x0418, 0x0300});
            table.put(0x2F8AB, new int [] {0x618E});
            table.put(0x040C, new int [] {0x041A, 0x0301});
            table.put(0x2F8AA, new int [] {0x617A});
            table.put(0xF929, new int [] {0x6717});
            table.put(0xF928, new int [] {0x5ECA});
            table.put(0xF927, new int [] {0x881F});
            table.put(0x2F8A9, new int [] {0x614C});
            table.put(0xF926, new int [] {0x81D8});
            table.put(0x2F8A8, new int [] {0x614E});
            table.put(0xF925, new int [] {0x62C9});
            table.put(0x2F8A7, new int [] {0x614C});
            table.put(0xF924, new int [] {0x8964});
            table.put(0x2F8A6, new int [] {0x6148});
            table.put(0xF923, new int [] {0x85CD});
            table.put(0x0407, new int [] {0x0406, 0x0308});
            table.put(0x2F8A5, new int [] {0x60C7});
            table.put(0xF922, new int [] {0x6FEB});
            table.put(0x2F8A4, new int [] {0x226D4});
            table.put(0xF921, new int [] {0x5D50});
            table.put(0x2F8A3, new int [] {0x6094});
            table.put(0xF920, new int [] {0x9E1E});
            table.put(0x2F8A2, new int [] {0x391C});
            table.put(0x0403, new int [] {0x0413, 0x0301});
            table.put(0x2F8A1, new int [] {0x393A});
            table.put(0x2F8A0, new int [] {0x6081});
            table.put(0x0401, new int [] {0x0415, 0x0308});
            table.put(0x0400, new int [] {0x0415, 0x0300});
            table.put(0xF91F, new int [] {0x862D});
            table.put(0xF91E, new int [] {0x721B});
            table.put(0xF91D, new int [] {0x6B04});
            table.put(0xF91C, new int [] {0x5375});
            table.put(0xF91B, new int [] {0x4E82});
            table.put(0xF91A, new int [] {0x99F1});
            table.put(0xF919, new int [] {0x916A});
            table.put(0x22ED, new int [] {0x22B5, 0x0338});
            table.put(0xF918, new int [] {0x843D});
            table.put(0x22EC, new int [] {0x22B4, 0x0338});
            table.put(0xF917, new int [] {0x73DE});
            table.put(0x22EB, new int [] {0x22B3, 0x0338});
            table.put(0xF916, new int [] {0x70D9});
            table.put(0x22EA, new int [] {0x22B2, 0x0338});
            table.put(0xF915, new int [] {0x6D1B});
            table.put(0xF914, new int [] {0x6A02});
            table.put(0xF913, new int [] {0x908F});
            table.put(0xF912, new int [] {0x88F8});
            table.put(0xF911, new int [] {0x87BA});
            table.put(0xF910, new int [] {0x863F});
            table.put(0x22E3, new int [] {0x2292, 0x0338});
            table.put(0xF90F, new int [] {0x7F85});
            table.put(0x22E2, new int [] {0x2291, 0x0338});
            table.put(0xF90E, new int [] {0x7669});
            table.put(0x22E1, new int [] {0x227D, 0x0338});
            table.put(0xF90D, new int [] {0x61F6});
            table.put(0x22E0, new int [] {0x227C, 0x0338});
            table.put(0xF90C, new int [] {0x5948});
            table.put(0xF90B, new int [] {0x5587});
            table.put(0xF90A, new int [] {0x91D1});
            table.put(0xF909, new int [] {0x5951});
            table.put(0xF908, new int [] {0x9F9C});
            table.put(0xF907, new int [] {0x9F9C});
            table.put(0xF906, new int [] {0x53E5});
            table.put(0xF905, new int [] {0x4E32});
            table.put(0xF904, new int [] {0x6ED1});
            table.put(0xF903, new int [] {0x8CC8});
            table.put(0xF902, new int [] {0x8ECA});
            table.put(0xF901, new int [] {0x66F4});
            table.put(0xF900, new int [] {0x8C48});
            table.put(0x00FF, new int [] {0x0079, 0x0308});
            table.put(0x00FD, new int [] {0x0079, 0x0301});
            table.put(0x00FC, new int [] {0x0075, 0x0308});
            table.put(0x00FB, new int [] {0x0075, 0x0302});
            table.put(0x00FA, new int [] {0x0075, 0x0301});
            table.put(0x00F9, new int [] {0x0075, 0x0300});
            table.put(0x00F6, new int [] {0x006F, 0x0308});
            table.put(0x00F5, new int [] {0x006F, 0x0303});
            table.put(0x00F4, new int [] {0x006F, 0x0302});
            table.put(0x00F3, new int [] {0x006F, 0x0301});
            table.put(0x00F2, new int [] {0x006F, 0x0300});
            table.put(0x00F1, new int [] {0x006E, 0x0303});
            table.put(0x00EF, new int [] {0x0069, 0x0308});
            table.put(0x00EE, new int [] {0x0069, 0x0302});
            table.put(0x00ED, new int [] {0x0069, 0x0301});
            table.put(0x00EC, new int [] {0x0069, 0x0300});
            table.put(0x00EB, new int [] {0x0065, 0x0308});
            table.put(0x00EA, new int [] {0x0065, 0x0302});
            table.put(0x00E9, new int [] {0x0065, 0x0301});
            table.put(0x00E8, new int [] {0x0065, 0x0300});
            table.put(0x00E7, new int [] {0x0063, 0x0327});
            table.put(0x00E5, new int [] {0x0061, 0x030A});
            table.put(0x00E4, new int [] {0x0061, 0x0308});
            table.put(0x00E3, new int [] {0x0061, 0x0303});
            table.put(0x00E2, new int [] {0x0061, 0x0302});
            table.put(0x00E1, new int [] {0x0061, 0x0301});
            table.put(0x00E0, new int [] {0x0061, 0x0300});
            table.put(0x00DD, new int [] {0x0059, 0x0301});
            table.put(0x00DC, new int [] {0x0055, 0x0308});
            table.put(0x00DB, new int [] {0x0055, 0x0302});
            table.put(0x00DA, new int [] {0x0055, 0x0301});
            table.put(0x22AF, new int [] {0x22AB, 0x0338});
            table.put(0x22AE, new int [] {0x22A9, 0x0338});
            table.put(0x22AD, new int [] {0x22A8, 0x0338});
            table.put(0x22AC, new int [] {0x22A2, 0x0338});
            table.put(0x00D9, new int [] {0x0055, 0x0300});
            table.put(0x00D6, new int [] {0x004F, 0x0308});
            table.put(0x00D5, new int [] {0x004F, 0x0303});
            table.put(0x00D4, new int [] {0x004F, 0x0302});
            table.put(0x00D3, new int [] {0x004F, 0x0301});
            table.put(0x00D2, new int [] {0x004F, 0x0300});
            table.put(0x00D1, new int [] {0x004E, 0x0303});
            table.put(0x309E, new int [] {0x309D, 0x3099});
            table.put(0x00CF, new int [] {0x0049, 0x0308});
            table.put(0x00CE, new int [] {0x0049, 0x0302});
            table.put(0x00CD, new int [] {0x0049, 0x0301});
            table.put(0x00CC, new int [] {0x0049, 0x0300});
            table.put(0x00CB, new int [] {0x0045, 0x0308});
            table.put(0x00CA, new int [] {0x0045, 0x0302});
            table.put(0x00C9, new int [] {0x0045, 0x0301});
            table.put(0x3094, new int [] {0x3046, 0x3099});
            table.put(0x00C8, new int [] {0x0045, 0x0300});
            table.put(0x00C7, new int [] {0x0043, 0x0327});
            table.put(0x00C5, new int [] {0x0041, 0x030A});
            table.put(0x00C4, new int [] {0x0041, 0x0308});
            table.put(0x00C3, new int [] {0x0041, 0x0303});
            table.put(0x00C2, new int [] {0x0041, 0x0302});
            table.put(0x00C1, new int [] {0x0041, 0x0301});
            table.put(0x00C0, new int [] {0x0041, 0x0300});
            table.put(0x307D, new int [] {0x307B, 0x309A});
            table.put(0x307C, new int [] {0x307B, 0x3099});
            table.put(0x2F89F, new int [] {0x5FF9});
            table.put(0x307A, new int [] {0x3078, 0x309A});
            table.put(0x2F89E, new int [] {0x5FD7});
            table.put(0x2F89D, new int [] {0x5FCD});
            table.put(0x2F89C, new int [] {0x5F9A});
            table.put(0x2F89B, new int [] {0x38E3});
            table.put(0x2F89A, new int [] {0x5F6B});
            table.put(0x3079, new int [] {0x3078, 0x3099});
            table.put(0x3077, new int [] {0x3075, 0x309A});
            table.put(0x3076, new int [] {0x3075, 0x3099});
            table.put(0x2F899, new int [] {0x5F62});
            table.put(0x3074, new int [] {0x3072, 0x309A});
            table.put(0x2F898, new int [] {0x261DA});
            table.put(0x3073, new int [] {0x3072, 0x3099});
            table.put(0x2F897, new int [] {0x232B8});
            table.put(0x2F896, new int [] {0x38C7});
            table.put(0x3071, new int [] {0x306F, 0x309A});
            table.put(0x2F895, new int [] {0x5F22});
            table.put(0x3070, new int [] {0x306F, 0x3099});
            table.put(0x2F894, new int [] {0x5F22});
            table.put(0x2F893, new int [] {0x8201});
            table.put(0x2F892, new int [] {0x22331});
            table.put(0x2F891, new int [] {0x22331});
            table.put(0x2F890, new int [] {0x5EFE});
            table.put(0x2F88F, new int [] {0x2A392});
            table.put(0x2F88E, new int [] {0x5ECA});
            table.put(0x2F88D, new int [] {0x5EB6});
            table.put(0x2F88C, new int [] {0x5EB3});
            table.put(0x2F88B, new int [] {0x5EB0});
            table.put(0x2F88A, new int [] {0x387C});
            table.put(0x3069, new int [] {0x3068, 0x3099});
            table.put(0x3067, new int [] {0x3066, 0x3099});
            table.put(0x3065, new int [] {0x3064, 0x3099});
            table.put(0x2F889, new int [] {0x22183});
            table.put(0x2F888, new int [] {0x3862});
            table.put(0x2F887, new int [] {0x5E69});
            table.put(0x3062, new int [] {0x3061, 0x3099});
            table.put(0x2F886, new int [] {0x5E3D});
            table.put(0x2F885, new int [] {0x5E28});
            table.put(0x3060, new int [] {0x305F, 0x3099});
            table.put(0x2F884, new int [] {0x5DFD});
            table.put(0x2F883, new int [] {0x382F});
            table.put(0x2F882, new int [] {0x5DE2});
            table.put(0x2F881, new int [] {0x5DE1});
            table.put(0x2F880, new int [] {0x5D7C});
            table.put(0x305E, new int [] {0x305D, 0x3099});
            table.put(0x305C, new int [] {0x305B, 0x3099});
            table.put(0x2F87F, new int [] {0x5D6B});
            table.put(0x305A, new int [] {0x3059, 0x3099});
            table.put(0x2F87E, new int [] {0x5D6E});
            table.put(0x2F87D, new int [] {0x21DE6});
            table.put(0x2F87C, new int [] {0x5D43});
            table.put(0x2F87B, new int [] {0x21DE4});
            table.put(0x2F87A, new int [] {0x5C8D});
            table.put(0x3058, new int [] {0x3057, 0x3099});
            table.put(0x3056, new int [] {0x3055, 0x3099});
            table.put(0x2F879, new int [] {0x5CC0});
            table.put(0x3054, new int [] {0x3053, 0x3099});
            table.put(0x2F878, new int [] {0x5C6E});
            table.put(0x2F877, new int [] {0x5C60});
            table.put(0x3052, new int [] {0x3051, 0x3099});
            table.put(0x2F876, new int [] {0x3781});
            table.put(0x2F875, new int [] {0x5C22});
            table.put(0x3050, new int [] {0x304F, 0x3099});
            table.put(0x2F874, new int [] {0x5F53});
            table.put(0x2F873, new int [] {0x5C06});
            table.put(0x2F872, new int [] {0x5BFF});
            table.put(0x2F871, new int [] {0x21B18});
            table.put(0x2F870, new int [] {0x5BF3});
            table.put(0x304E, new int [] {0x304D, 0x3099});
            table.put(0x304C, new int [] {0x304B, 0x3099});
            table.put(0x2F86F, new int [] {0x5BE7});
            table.put(0x2F86E, new int [] {0x5BD8});
            table.put(0x2F86D, new int [] {0x5BC3});
            table.put(0x2F86C, new int [] {0x219C8});
            table.put(0x2F86B, new int [] {0x5B3E});
            table.put(0x2F86A, new int [] {0x5B3E});
            table.put(0x2F869, new int [] {0x5B08});
            table.put(0x2F868, new int [] {0x36FC});
            table.put(0x2F867, new int [] {0x36EE});
            table.put(0x0CCB, new int [] {0x0CC6, 0x0CC2, 0x0CD5});
            table.put(0x2F866, new int [] {0x5A66});
            table.put(0x0CCA, new int [] {0x0CC6, 0x0CC2});
            table.put(0x2F865, new int [] {0x59D8});
            table.put(0x2F864, new int [] {0x5A27});
            table.put(0x2F863, new int [] {0x5A1B});
            table.put(0x03D4, new int [] {0x03D2, 0x0308});
            table.put(0x2F862, new int [] {0x59EC});
            table.put(0x03D3, new int [] {0x03D2, 0x0301});
            table.put(0x2F861, new int [] {0x216EA});
            table.put(0x2F860, new int [] {0x216A8});
            table.put(0x0CC8, new int [] {0x0CC6, 0x0CD6});
            table.put(0x0CC7, new int [] {0x0CC6, 0x0CD5});
            table.put(0x2F85F, new int [] {0x5962});
            table.put(0x2F85E, new int [] {0x5922});
            table.put(0x2F85D, new int [] {0x591A});
            table.put(0x0CC0, new int [] {0x0CBF, 0x0CD5});
            table.put(0x03CE, new int [] {0x03C9, 0x0301});
            table.put(0x2F85C, new int [] {0x5906});
            table.put(0x03CD, new int [] {0x03C5, 0x0301});
            table.put(0x2F85B, new int [] {0x58F7});
            table.put(0x03CC, new int [] {0x03BF, 0x0301});
            table.put(0x2F85A, new int [] {0x58F2});
            table.put(0x03CB, new int [] {0x03C5, 0x0308});
            table.put(0x03CA, new int [] {0x03B9, 0x0308});
            table.put(0x2F859, new int [] {0x214E4});
            table.put(0x2F858, new int [] {0x58AC});
            table.put(0x2F857, new int [] {0x5831});
            table.put(0x2F856, new int [] {0x5832});
            table.put(0x2F855, new int [] {0x578B});
            table.put(0x2F854, new int [] {0x580D});
            table.put(0x2F853, new int [] {0x57F4});
            table.put(0x2F852, new int [] {0x57CE});
            table.put(0x2F851, new int [] {0x58EE});
            table.put(0x2F850, new int [] {0x5207});
            table.put(0x2F84F, new int [] {0x5674});
            table.put(0x2F84E, new int [] {0x5651});
            table.put(0x2F84D, new int [] {0x5717});
            table.put(0x2F84C, new int [] {0x5606});
            table.put(0x2F84B, new int [] {0x5716});
            table.put(0x2F84A, new int [] {0x55C2});
            table.put(0x2F849, new int [] {0x55B3});
            table.put(0x2F848, new int [] {0x55AB});
            table.put(0x2F847, new int [] {0x5599});
            table.put(0x2F846, new int [] {0x5584});
            table.put(0x2F845, new int [] {0x5584});
            table.put(0x2F844, new int [] {0x5563});
            table.put(0x2F843, new int [] {0x5553});
            table.put(0x2F842, new int [] {0x5510});
            table.put(0x2F841, new int [] {0x54F6});
            table.put(0x2F840, new int [] {0x54A2});
            table.put(0x03B0, new int [] {0x03C5, 0x0308, 0x0301});
            table.put(0x2F83F, new int [] {0x5468});
            table.put(0x2F83E, new int [] {0x5448});
            table.put(0x03AF, new int [] {0x03B9, 0x0301});
            table.put(0x2F83D, new int [] {0x5438});
            table.put(0x03AE, new int [] {0x03B7, 0x0301});
            table.put(0x2F83C, new int [] {0x549E});
            table.put(0x03AD, new int [] {0x03B5, 0x0301});
            table.put(0x2F83B, new int [] {0x5406});
            table.put(0x03AC, new int [] {0x03B1, 0x0301});
            table.put(0x2F83A, new int [] {0x53F1});
            table.put(0x03AB, new int [] {0x03A5, 0x0308});
            table.put(0x03AA, new int [] {0x0399, 0x0308});
            table.put(0x2F839, new int [] {0x53EB});
            table.put(0x2F838, new int [] {0x20B63});
            table.put(0x2F837, new int [] {0x53DF});
            table.put(0x2F836, new int [] {0x53CA});
            table.put(0x2F835, new int [] {0x7070});
            table.put(0x2F834, new int [] {0x20A2C});
            table.put(0x2F833, new int [] {0x537F});
            table.put(0x2F832, new int [] {0x537F});
            table.put(0x2F831, new int [] {0x537F});
            table.put(0x2289, new int [] {0x2287, 0x0338});
            table.put(0x2F830, new int [] {0x537D});
            table.put(0x2288, new int [] {0x2286, 0x0338});
            table.put(0x2285, new int [] {0x2283, 0x0338});
            table.put(0x2284, new int [] {0x2282, 0x0338});
            table.put(0x2281, new int [] {0x227B, 0x0338});
            table.put(0x2280, new int [] {0x227A, 0x0338});
            table.put(0x2F82F, new int [] {0x5373});
            table.put(0x2F82E, new int [] {0x535A});
            table.put(0x2F82D, new int [] {0x5351});
            table.put(0x2F82C, new int [] {0x5349});
            table.put(0x2F82B, new int [] {0x5317});
            table.put(0x2F82A, new int [] {0x5306});
            table.put(0x2F829, new int [] {0x5305});
            table.put(0x2F828, new int [] {0x52FA});
            table.put(0x2F827, new int [] {0x52E4});
            table.put(0x2F826, new int [] {0x52C9});
            table.put(0x2F825, new int [] {0x52C7});
            table.put(0x2F824, new int [] {0x3515});
            table.put(0x2F823, new int [] {0x5277});
            table.put(0x2F822, new int [] {0x5272});
            table.put(0x2F821, new int [] {0x5246});
            table.put(0x2279, new int [] {0x2277, 0x0338});
            table.put(0x2F820, new int [] {0x523B});
            table.put(0x2278, new int [] {0x2276, 0x0338});
            table.put(0x2275, new int [] {0x2273, 0x0338});
            table.put(0x2274, new int [] {0x2272, 0x0338});
            table.put(0x2271, new int [] {0x2265, 0x0338});
            table.put(0x2270, new int [] {0x2264, 0x0338});
            table.put(0x2F81F, new int [] {0x34DF});
            table.put(0x2F81E, new int [] {0x5203});
            table.put(0x2F81D, new int [] {0x51F5});
            table.put(0x2F81C, new int [] {0x291DF});
            table.put(0x2F81B, new int [] {0x51B5});
            table.put(0xFB4E, new int [] {0x05E4, 0x05BF});
            table.put(0x2F81A, new int [] {0x51AC});
            table.put(0xFB4D, new int [] {0x05DB, 0x05BF});
            table.put(0xFB4C, new int [] {0x05D1, 0x05BF});
            table.put(0xFB4B, new int [] {0x05D5, 0x05B9});
            table.put(0x226F, new int [] {0x003E, 0x0338});
            table.put(0xFB4A, new int [] {0x05EA, 0x05BC});
            table.put(0x226E, new int [] {0x003C, 0x0338});
            table.put(0x226D, new int [] {0x224D, 0x0338});
            table.put(0x2F819, new int [] {0x4ECC});
            table.put(0x2F818, new int [] {0x51A4});
            table.put(0x2F817, new int [] {0x5197});
            table.put(0x2F816, new int [] {0x2054B});
            table.put(0xFB49, new int [] {0x05E9, 0x05BC});
            table.put(0x2F815, new int [] {0x518D});
            table.put(0xFB48, new int [] {0x05E8, 0x05BC});
            table.put(0x2F814, new int [] {0x5167});
            table.put(0xFB47, new int [] {0x05E7, 0x05BC});
            table.put(0x2F813, new int [] {0x34B9});
            table.put(0xFB46, new int [] {0x05E6, 0x05BC});
            table.put(0x2F812, new int [] {0x2051C});
            table.put(0x2F811, new int [] {0x5177});
            table.put(0xFB44, new int [] {0x05E4, 0x05BC});
            table.put(0x2F810, new int [] {0x5164});
            table.put(0xFB43, new int [] {0x05E3, 0x05BC});
            table.put(0xFB41, new int [] {0x05E1, 0x05BC});
            table.put(0xFB40, new int [] {0x05E0, 0x05BC});
            table.put(0x2262, new int [] {0x2261, 0x0338});
            table.put(0x2260, new int [] {0x003D, 0x0338});
            table.put(0x2F80F, new int [] {0x5154});
            table.put(0x2F80E, new int [] {0x514D});
            table.put(0x2F80D, new int [] {0x2063A});
            table.put(0x2F80C, new int [] {0x349E});
            table.put(0x2F80B, new int [] {0x50CF});
            table.put(0xFB3E, new int [] {0x05DE, 0x05BC});
            table.put(0x2F80A, new int [] {0x50E7});
            table.put(0xFB3C, new int [] {0x05DC, 0x05BC});
            table.put(0xFB3B, new int [] {0x05DB, 0x05BC});
            table.put(0xFB3A, new int [] {0x05DA, 0x05BC});
            table.put(0x2F809, new int [] {0x5099});
            table.put(0x2F808, new int [] {0x507A});
            table.put(0x2F807, new int [] {0x5002});
            table.put(0x2F806, new int [] {0x4FBB});
            table.put(0xFB39, new int [] {0x05D9, 0x05BC});
            table.put(0x2F805, new int [] {0x4FAE});
            table.put(0xFB38, new int [] {0x05D8, 0x05BC});
            table.put(0x2F804, new int [] {0x4F60});
            table.put(0x2F803, new int [] {0x20122});
            table.put(0xFB36, new int [] {0x05D6, 0x05BC});
            table.put(0x2F802, new int [] {0x4E41});
            table.put(0xFB35, new int [] {0x05D5, 0x05BC});
            table.put(0x2F801, new int [] {0x4E38});
            table.put(0xFB34, new int [] {0x05D4, 0x05BC});
            table.put(0x2F800, new int [] {0x4E3D});
            table.put(0x06D3, new int [] {0x06D2, 0x0654});
            table.put(0xFB33, new int [] {0x05D3, 0x05BC});
            table.put(0xFB32, new int [] {0x05D2, 0x05BC});
            table.put(0xFB31, new int [] {0x05D1, 0x05BC});
            table.put(0xFB30, new int [] {0x05D0, 0x05BC});
            table.put(0xFB2F, new int [] {0x05D0, 0x05B8});
            table.put(0xFB2E, new int [] {0x05D0, 0x05B7});
            table.put(0xFB2D, new int [] {0x05E9, 0x05BC, 0x05C2});
            table.put(0xFB2C, new int [] {0x05E9, 0x05BC, 0x05C1});
            table.put(0xFB2B, new int [] {0x05E9, 0x05C2});
            table.put(0xFB2A, new int [] {0x05E9, 0x05C1});
            table.put(0x2249, new int [] {0x2248, 0x0338});
            table.put(0x2247, new int [] {0x2245, 0x0338});
            table.put(0x06C2, new int [] {0x06C1, 0x0654});
            table.put(0x06C0, new int [] {0x06D5, 0x0654});
            table.put(0x2244, new int [] {0x2243, 0x0338});
            table.put(0x0FB9, new int [] {0x0F90, 0x0FB5});
            table.put(0x2241, new int [] {0x223C, 0x0338});
            table.put(0xFB1F, new int [] {0x05F2, 0x05B7});
            table.put(0xFB1D, new int [] {0x05D9, 0x05B4});
            table.put(0x0FAC, new int [] {0x0FAB, 0x0FB7});
            table.put(0x0FA7, new int [] {0x0FA6, 0x0FB7});
            table.put(0x0FA2, new int [] {0x0FA1, 0x0FB7});
            table.put(0x2226, new int [] {0x2225, 0x0338});
            table.put(0x2224, new int [] {0x2223, 0x0338});
            table.put(0x220C, new int [] {0x220B, 0x0338});
            table.put(0x2209, new int [] {0x2208, 0x0338});
            table.put(0x0390, new int [] {0x03B9, 0x0308, 0x0301});
            table.put(0x2204, new int [] {0x2203, 0x0338});
            table.put(0x038F, new int [] {0x03A9, 0x0301});
            table.put(0x038E, new int [] {0x03A5, 0x0301});
            table.put(0x038C, new int [] {0x039F, 0x0301});
            table.put(0x09DF, new int [] {0x09AF, 0x09BC});
            table.put(0x038A, new int [] {0x0399, 0x0301});
            table.put(0x09DD, new int [] {0x09A2, 0x09BC});
            table.put(0x09DC, new int [] {0x09A1, 0x09BC});
            table.put(0x0389, new int [] {0x0397, 0x0301});
            table.put(0x0388, new int [] {0x0395, 0x0301});
            table.put(0x0387, new int [] {0x00B7});
            table.put(0x0386, new int [] {0x0391, 0x0301});
            table.put(0x0385, new int [] {0x00A8, 0x0301});
            table.put(0x037E, new int [] {0x003B});
            table.put(0x09CC, new int [] {0x09C7, 0x09D7});
            table.put(0x09CB, new int [] {0x09C7, 0x09BE});
            table.put(0x0374, new int [] {0x02B9});
            table.put(0x0C48, new int [] {0x0C46, 0x0C56});
            table.put(0x0F9D, new int [] {0x0F9C, 0x0FB7});
            table.put(0x0344, new int [] {0x0308, 0x0301});
            table.put(0x0343, new int [] {0x0313});
            table.put(0x0341, new int [] {0x0301});
            table.put(0x0340, new int [] {0x0300});
            table.put(0x0F93, new int [] {0x0F92, 0x0FB7});
            table.put(0x0F81, new int [] {0x0F71, 0x0F80});
            table.put(0x0F78, new int [] {0x0FB3, 0x0F80});
            table.put(0x1D1C0, new int [] {0x1D1BA, 0x1D165, 0x1D16F});
            table.put(0x0F76, new int [] {0x0FB2, 0x0F80});
            table.put(0x0F75, new int [] {0x0F71, 0x0F74});
            table.put(0x0F73, new int [] {0x0F71, 0x0F72});
            table.put(0x1D1BF, new int [] {0x1D1B9, 0x1D165, 0x1D16F});
            table.put(0x1D1BE, new int [] {0x1D1BA, 0x1D165, 0x1D16E});
            table.put(0x1D1BD, new int [] {0x1D1B9, 0x1D165, 0x1D16E});
            table.put(0x1D1BC, new int [] {0x1D1BA, 0x1D165});
            table.put(0x1D1BB, new int [] {0x1D1B9, 0x1D165});
            table.put(0x0F69, new int [] {0x0F40, 0x0FB5});
            table.put(0x0F5C, new int [] {0x0F5B, 0x0FB7});
            table.put(0xFAD9, new int [] {0x9F8E});
            table.put(0xFAD8, new int [] {0x9F43});
            table.put(0xFAD7, new int [] {0x27ED3});
            table.put(0xFAD6, new int [] {0x25CD0});
            table.put(0xFAD5, new int [] {0x25249});
            table.put(0xFAD4, new int [] {0x4039});
            table.put(0xFAD3, new int [] {0x4018});
            table.put(0xFAD2, new int [] {0x3B9D});
            table.put(0xFAD1, new int [] {0x233D5});
            table.put(0xFAD0, new int [] {0x22844});
            table.put(0x0F57, new int [] {0x0F56, 0x0FB7});
            table.put(0x0F52, new int [] {0x0F51, 0x0FB7});
            table.put(0xFACF, new int [] {0x2284A});
            table.put(0xFACE, new int [] {0x9F9C});
            table.put(0xFACD, new int [] {0x9B12});
            table.put(0xFACC, new int [] {0x983B});
            table.put(0xFACB, new int [] {0x980B});
            table.put(0xFACA, new int [] {0x97FF});
            table.put(0x0F4D, new int [] {0x0F4C, 0x0FB7});
            table.put(0xFAC9, new int [] {0x97DB});
            table.put(0xFAC8, new int [] {0x9756});
            table.put(0xFAC7, new int [] {0x96E3});
            table.put(0xFAC6, new int [] {0x967C});
            table.put(0xFAC5, new int [] {0x9276});
            table.put(0x2ADC, new int [] {0x2ADD, 0x0338});
            table.put(0xFAC4, new int [] {0x9199});
            table.put(0xFAC3, new int [] {0x9072});
            table.put(0xFAC2, new int [] {0x8F38});
            table.put(0xFAC1, new int [] {0x8D08});
            table.put(0xFAC0, new int [] {0x8B8A});
            table.put(0x0F43, new int [] {0x0F42, 0x0FB7});
            table.put(0xFABF, new int [] {0x8B39});
            table.put(0xFABE, new int [] {0x8AED});
            table.put(0xFABD, new int [] {0x8AFE});
            table.put(0xFABC, new int [] {0x8B01});
            table.put(0xFABB, new int [] {0x8ACB});
            table.put(0xFABA, new int [] {0x8AF8});
            table.put(0xFAB9, new int [] {0x8ABF});
            table.put(0xFAB8, new int [] {0x8996});
            table.put(0xFAB7, new int [] {0x8986});
            table.put(0xFAB6, new int [] {0x8941});
            table.put(0xFAB5, new int [] {0x8779});
            table.put(0xFAB4, new int [] {0x83EF});
            table.put(0xFAB3, new int [] {0x8352});
            table.put(0xFAB2, new int [] {0x8005});
            table.put(0xFAB1, new int [] {0x7F3E});
            table.put(0xFAB0, new int [] {0x7DF4});
            table.put(0xFAAF, new int [] {0x7D5B});
            table.put(0xFAAE, new int [] {0x7C7B});
            table.put(0xFAAD, new int [] {0x7BC0});
            table.put(0xFAAC, new int [] {0x7AB1});
            table.put(0xFAAB, new int [] {0x78CC});
            table.put(0x2FA1D, new int [] {0x2A600});
            table.put(0x21CF, new int [] {0x21D2, 0x0338});
            table.put(0xFAAA, new int [] {0x7740});
            table.put(0x2FA1C, new int [] {0x9F3B});
            table.put(0x21CE, new int [] {0x21D4, 0x0338});
            table.put(0x2FA1B, new int [] {0x9F16});
            table.put(0x21CD, new int [] {0x21D0, 0x0338});
            table.put(0x2FA1A, new int [] {0x9F0F});
            table.put(0xFAA9, new int [] {0x774A});
            table.put(0xFAA8, new int [] {0x76F4});
            table.put(0xFAA7, new int [] {0x76DB});
            table.put(0x2FA19, new int [] {0x9F05});
            table.put(0xFAA6, new int [] {0x76CA});
            table.put(0x2FA18, new int [] {0x9EFE});
            table.put(0xFAA5, new int [] {0x761F});
            table.put(0x2FA17, new int [] {0x9EF9});
            table.put(0xFAA4, new int [] {0x761D});
            table.put(0x2FA16, new int [] {0x4D56});
            table.put(0xFAA3, new int [] {0x753B});
            table.put(0x2FA15, new int [] {0x9EBB});
            table.put(0xFAA2, new int [] {0x7506});
            table.put(0x2FA14, new int [] {0x2A291});
            table.put(0xFAA1, new int [] {0x7471});
            table.put(0x2FA13, new int [] {0x2A20E});
            table.put(0xFAA0, new int [] {0x732A});
            table.put(0x2FA12, new int [] {0x2A105});
            table.put(0x2FA11, new int [] {0x4CF8});
            table.put(0x2FA10, new int [] {0x2A0CE});
            table.put(0x2FA0F, new int [] {0x9D67});
            table.put(0x2FA0E, new int [] {0x4CED});
            table.put(0x2FA0D, new int [] {0x4CCE});
            table.put(0x2FA0C, new int [] {0x9CFD});
            table.put(0x2FA0B, new int [] {0x9C40});
            table.put(0x2FA0A, new int [] {0x9B12});
            table.put(0x2FA09, new int [] {0x29B30});
            table.put(0x0626, new int [] {0x064A, 0x0654});
            table.put(0x2FA08, new int [] {0x4BCE});
            table.put(0x0625, new int [] {0x0627, 0x0655});
            table.put(0x2FA07, new int [] {0x99FE});
            table.put(0x0624, new int [] {0x0648, 0x0654});
            table.put(0x2FA06, new int [] {0x99C2});
            table.put(0x0623, new int [] {0x0627, 0x0654});
            table.put(0x2FA05, new int [] {0x99A7});
            table.put(0x0622, new int [] {0x0627, 0x0653});
            table.put(0x2FA04, new int [] {0x9929});
            table.put(0x2FA03, new int [] {0x4B33});
            table.put(0x2FA02, new int [] {0x98E2});
            table.put(0x2FA01, new int [] {0x295B6});
            table.put(0x2FA00, new int [] {0x9829});
            table.put(0x21AE, new int [] {0x2194, 0x0338});
            table.put(0x095F, new int [] {0x092F, 0x093C});
            table.put(0x095E, new int [] {0x092B, 0x093C});
            table.put(0x095D, new int [] {0x0922, 0x093C});
            table.put(0x095C, new int [] {0x0921, 0x093C});
            table.put(0x095B, new int [] {0x091C, 0x093C});
            table.put(0x095A, new int [] {0x0917, 0x093C});
            table.put(0x0959, new int [] {0x0916, 0x093C});
            table.put(0x0958, new int [] {0x0915, 0x093C});
            table.put(0x0934, new int [] {0x0933, 0x093C});
            table.put(0x0931, new int [] {0x0930, 0x093C});
            return table;
        }
    }
}
